@@ -19,6 +19,7 @@
 package edu.berkeley.boinc.client;
 
 import edu.berkeley.boinc.utils.*;
+
 import java.io.File;
 import java.io.FileInputStream;
 import java.io.FileOutputStream;
@@ -29,26 +30,38 @@ import java.io.OutputStream;
 import java.security.MessageDigest;
 import java.security.NoSuchAlgorithmException;
 import java.util.ArrayList;
+import java.util.List;
 import java.util.Locale;
 import java.util.Timer;
 import java.util.TimerTask;
-import android.app.NotificationManager;
 import android.app.Service;
 import android.content.BroadcastReceiver;
 import android.content.Context;
 import android.content.Intent;
 import android.content.IntentFilter;
-import android.os.Binder;
+import android.graphics.Bitmap;
+import android.os.AsyncTask;
 import android.os.Build;
 import android.os.IBinder;
 import android.os.PowerManager;
+import android.os.RemoteException;
 import android.util.Log;
-import edu.berkeley.boinc.AppPreferences;
 import edu.berkeley.boinc.R;
+import edu.berkeley.boinc.mutex.BoincMutex;
+import edu.berkeley.boinc.rpc.AccountIn;
+import edu.berkeley.boinc.rpc.AccountOut;
+import edu.berkeley.boinc.rpc.AcctMgrRPCReply;
 import edu.berkeley.boinc.rpc.CcState;
 import edu.berkeley.boinc.rpc.CcStatus;
 import edu.berkeley.boinc.rpc.GlobalPreferences;
+import edu.berkeley.boinc.rpc.HostInfo;
+import edu.berkeley.boinc.rpc.ImageWrapper;
+import edu.berkeley.boinc.rpc.Message;
+import edu.berkeley.boinc.rpc.Notice;
+import edu.berkeley.boinc.rpc.Project;
+import edu.berkeley.boinc.rpc.ProjectConfig;
 import edu.berkeley.boinc.rpc.ProjectInfo;
+import edu.berkeley.boinc.rpc.Result;
 import edu.berkeley.boinc.rpc.Transfer;
 import edu.berkeley.boinc.rpc.AcctMgrInfo;
 
@@ -61,13 +74,13 @@ import edu.berkeley.boinc.rpc.AcctMgrInfo;
  */
 public class Monitor extends Service {
 	
+	private static BoincMutex mutex = new BoincMutex(); // holds the BOINC mutex, only compute if acquired
 	private static ClientStatus clientStatus; //holds the status of the client as determined by the Monitor
 	private static AppPreferences appPrefs; //hold the status of the app, controlled by AppPreferences
+	private static DeviceStatus deviceStatus; // holds the status of the device, i.e. status information that can only be obtained trough Java APIs
 	
 	public ClientInterfaceImplementation clientInterface = new ClientInterfaceImplementation(); //provides functions for interaction with client via rpc
 	
-	public static Boolean monitorActive = false;
-	
 	// XML defined variables, populated in onCreate
 	private String fileNameClient; 
 	private String fileNameCLI; 
@@ -78,27 +91,17 @@ public class Monitor extends Service {
 	private String boincWorkingDir; 
 	private Integer clientStatusInterval;
 	private Integer deviceStatusIntervalScreenOff;
+	private String clientSocketAddress;
 	
 	private Timer updateTimer = new Timer(true); // schedules frequent client status update
 	private TimerTask statusUpdateTask = new StatusUpdateTimerTask();
-	private boolean updateBroadcastEnabled = true;
-	private DeviceStatus deviceStatus = null;
+	private boolean updateBroadcastEnabled = false;
 	private Integer screenOffStatusOmitCounter = 0;
 	
 	// screen on/off updated by screenOnOffBroadcastReceiver
 	private boolean screenOn = false;
 	
-// attributes and methods related to Android Service life-cycle
-	/**
-	 * Extension of Android's Binder class to return instance of this service
-	 * allows components bound to this service, to access its functions and attributes
-	 */
-	public class LocalBinder extends Binder {
-        public Monitor getService() {
-            return Monitor.this;
-        }
-    }
-    private final IBinder mBinder = new LocalBinder();
+	private boolean forceReinstall = false; // for debugging purposes //TODO
 
     @Override
     public IBinder onBind(Intent intent) {
@@ -108,7 +111,8 @@ public class Monitor extends Service {
 	
 	@Override
     public void onCreate() {
-		if(Logging.ERROR) Log.d(Logging.TAG,"Monitor onCreate()");
+		
+		Log.d(Logging.TAG,"Monitor onCreate()");
 		
 		// populate attributes with XML resource values
 		boincWorkingDir = getString(R.string.client_path); 
@@ -120,10 +124,13 @@ public class Monitor extends Service {
 		fileNameAllProjectsList = getString(R.string.all_projects_list); 
 		clientStatusInterval = getResources().getInteger(R.integer.status_update_interval_ms);
 		deviceStatusIntervalScreenOff = getResources().getInteger(R.integer.device_status_update_screen_off_every_X_loop);
+		clientSocketAddress = getString(R.string.client_socket_address); 
 		
 		// initialize singleton helper classes and provide application context
 		clientStatus = new ClientStatus(this);
 		getAppPrefs().readPrefs(this);
+		deviceStatus = new DeviceStatus(this, getAppPrefs());
+		if(Logging.ERROR) Log.d(Logging.TAG,"Monitor onCreate(): singletons initialized");
 		
 		// set current screen on/off status
 		PowerManager pm = (PowerManager)
@@ -138,35 +145,66 @@ public class Monitor extends Service {
         IntentFilter offFilter = new IntentFilter (Intent.ACTION_SCREEN_OFF); 
         registerReceiver(screenOnOffReceiver, onFilter);
         registerReceiver(screenOnOffReceiver, offFilter);
-		
-        // register and start update task
-        // using .scheduleAtFixedRate() can cause a series of bunched-up runs
-        // when previous executions are delayed (e.g. during clientSetup() )
-        updateTimer.schedule(statusUpdateTask, 0, clientStatusInterval);
 	}
 	
     @Override
     public void onDestroy() {
     	if(Logging.ERROR) Log.d(Logging.TAG,"Monitor onDestroy()");
     	
-    	// remove screen on/off receiver
-    	unregisterReceiver(screenOnOffReceiver);
-    	
-        // Cancel the persistent notification.
-    	((NotificationManager)getSystemService(Service.NOTIFICATION_SERVICE)).cancel(getResources().getInteger(R.integer.autostart_notification_id));
+    	updateBroadcastEnabled = false; // prevent broadcast from currently running update task
+		updateTimer.cancel(); // cancel task
+		
+    	// there might be still other AsyncTasks executing RPCs
+    	// close sockets in a synchronized way
+		clientInterface.close();
+		
+    	try {
+    		// remove screen on/off receiver
+    		unregisterReceiver(screenOnOffReceiver);
+    	} catch (Exception ex) {}
         
     	updateBroadcastEnabled = false; // prevent broadcast from currently running update task
 		updateTimer.cancel(); // cancel task
 		
+		mutex.release(); // release BOINC mutex
+		
 		 // release locks, if held.
-		clientStatus.setWakeLock(false);
-		clientStatus.setWifiLock(false);
+		try {
+			clientStatus.setWakeLock(false);
+			clientStatus.setWifiLock(false);
+		} catch (Exception ex) {}
     }
 
     @Override
     public int onStartCommand(Intent intent, int flags, int startId) {	
-    	//this gets called after startService(intent) (either by BootReceiver or AndroidBOINCActivity, depending on the user's autostart configuration)
+    	//this gets called after startService(intent) (either by BootReceiver or SplashActivity, depending on the user's autostart configuration)
     	if(Logging.ERROR) Log.d(Logging.TAG, "Monitor onStartCommand()");
+		
+		// try to acquire BOINC mutex
+    	// run here in order to recover, if mutex holding app gets closed.
+		if(!updateBroadcastEnabled && mutex.acquire()) {
+			updateBroadcastEnabled = true;
+	        // register and start update task
+	        // using .scheduleAtFixedRate() can cause a series of bunched-up runs
+	        // when previous executions are delayed (e.g. during clientSetup() )
+	        updateTimer.schedule(statusUpdateTask, 0, clientStatusInterval);
+		}
+		if(!mutex.acquired) if(Logging.ERROR) Log.e(Logging.TAG, "Monitor.onStartCommand: mutex acquisition failed, do not start BOINC.");
+
+		// execute action if one is explicitly requested (e.g. from notification)
+    	if(intent != null) {
+			int actionCode = intent.getIntExtra("action", -1);
+	    	if(Logging.DEBUG) Log.d(Logging.TAG, "Monitor.onStartCommand() with action code: " + actionCode);
+			switch(actionCode) {
+			case 1: // suspend
+				new SetClientRunModeAsync().execute(BOINCDefs.RUN_MODE_NEVER);
+				break;
+			case 2: // resume
+				new SetClientRunModeAsync().execute(BOINCDefs.RUN_MODE_AUTO);
+				break;
+			}
+    	}
+		
 		/*
 		 * START_STICKY causes service to stay in memory until stopSelf() is called, even if all
 		 * Activities get destroyed by the system. Important for GUI keep-alive
@@ -203,115 +241,43 @@ public class Monitor extends Service {
 		}
 		return appPrefs;
 	}
+
+	/**
+	 * Retrieve singleton of DeviceStatus.
+	 * @return DeviceStatus, represents data model of device information reported to the client
+	 * @throws Exception if deviceStatus hast not been initialized
+	 */
+	public static DeviceStatus getDeviceStatus() throws Exception {//singleton pattern
+		if (deviceStatus == null) {
+			// device status needs application context, but context might not be available
+			// in static code. functions have to deal with Exception!
+			if(Logging.WARNING) Log.w(Logging.TAG,"getDeviceStatus: deviceStatus not yet initialized");
+			throw new Exception("deviceStatus not initialized");
+		}
+		return deviceStatus;
+	}
 // --end-- singleton getter
 	
 // public methods for Activities
-    /**
-     * read BOINC's all_project_list.xml and filters output for device's BOINC platform
-     * stores list of projects in ClienStatus class.
-     * Content does not change during runtime, call only upon start.
-     */
-	public void readAndroidProjectsList() {
-		// try to get current client status from monitor
-		ClientStatus status;
-		try{
-			status  = Monitor.getClientStatus();
-		} catch (Exception e){
-			if(Logging.WARNING) Log.w(Logging.TAG,"Monitor.readAndroidProjectList: Could not load data, clientStatus not initialized.");
-			return;
-		}
-		
-		ArrayList<ProjectInfo> allProjects = clientInterface.getAllProjectsList();
-		ArrayList<ProjectInfo> androidProjects = new ArrayList<ProjectInfo>();
-		
-		if(allProjects == null) return;
-		
-		String platform = getString(getBoincPlatform());
-		if(Logging.DEBUG) Log.d(Logging.TAG, "readAndroidProjectsList for platform: " + platform);
-		
-		//filter projects that do not support Android
-		for (ProjectInfo project: allProjects) {
-			for(String supportedPlatform: project.platforms) {
-				if(supportedPlatform.contains(platform) && !androidProjects.contains(project)) {
-					androidProjects.add(project);
-					break;
-				}
-			}
-		}
-		
-		// set list in ClientStatus
-		status.setSupportedProjects(androidProjects);
+	/**
+	 * Indicates whether service was able to obtain BOINC mutex.
+	 * If not, BOINC has not started and all other calls will fail.
+	 * @return BOINC mutex acquisition successful
+	 */
+	public boolean boincMutexAcquired() {
+		return mutex.acquired;
 	}
-
+	
     /**
      * Force refresh of client status data model, will fire Broadcast upon success.
      */
     public void forceRefresh() {
+    	if(!mutex.acquired) return; // do not try to update if client is not running
     	if(Logging.DEBUG) Log.d(Logging.TAG,"forceRefresh()");
     	try{
     		updateTimer.schedule(new StatusUpdateTimerTask(), 0);
     	} catch (Exception e){} // throws IllegalStateException if called after timer got cancelled, i.e. after manual shutdown
     }
-    
-    /**
-     * Quit BOINC client.
-     * Tries to quit BOINC client process gracefully, kills the process if no reaction within defined time frame 
-     */
-    public void quitClient() {
-		// try to get current client status from monitor
-		ClientStatus status = null;
-		try{
-			status  = Monitor.getClientStatus();
-		} catch (Exception e){
-			if(Logging.WARNING) Log.w(Logging.TAG,"Monitor.quitClient: Could not load data, clientStatus not initialized.");
-			// do not return here, try to shut down without publishing status
-		}
-    	String processName = boincWorkingDir + fileNameClient;
-    	
-    	updateBroadcastEnabled = false; // prevent broadcast from currently running update task
-		updateTimer.cancel(); // cancel task
-    	// no scheduled RPCs anymore
-    	
-    	// set client status to SETUP_STATUS_CLOSING to adapt layout accordingly
-		if(status!=null)status.setSetupStatus(ClientStatus.SETUP_STATUS_CLOSING,true);
-    	
-    	// try graceful shutdown via RPC
-		clientInterface.quit();
-    	
-    	// there might be still other AsyncTasks executing RPCs
-    	// close sockets in a synchronized way
-		clientInterface.close();
-    	// there are now no more RPCs...
-    	
-    	// graceful RPC shutdown waiting period...
-    	Boolean success = false;
-    	Integer attempts = getApplicationContext().getResources().getInteger(R.integer.shutdown_graceful_rpc_check_attempts);
-    	Integer sleepPeriod = getApplicationContext().getResources().getInteger(R.integer.shutdown_graceful_rpc_check_rate_ms);
-    	for(int x = 0; x < attempts; x++) {
-    		try {
-    			Thread.sleep(sleepPeriod);
-    		} catch (Exception e) {}
-    		if(getPidForProcessName(processName) == null) { //client is now closed
-        		if(Logging.DEBUG) Log.d(Logging.TAG,"quitClient: gracefull RPC shutdown successful after " + x + " seconds");
-    			success = true;
-    			x = attempts;
-    		}
-    	}
-    	
-    	if(!success) {
-    		// graceful RPC shutdown was not successful, try OS signals
-        	quitProcessOsLevel(processName);
-    	}
-    	
-    	// cancel notification
-		ClientNotification.getInstance(getApplicationContext()).cancel();
-    	
-    	// set client status to SETUP_STATUS_CLOSED to adapt layout accordingly
-		if(status!=null)status.setSetupStatus(ClientStatus.SETUP_STATUS_CLOSED,true);
-		
-		//stop service, triggers onDestroy
-		stopSelf();
-    }
 	
 	/**
 	 * Determines BOINC platform name corresponding to device's cpu architecture (ARM, x86 or MIPS).
@@ -341,17 +307,6 @@ public class Monitor extends Service {
 	public String getAuthFilePath(){
 		return boincWorkingDir + fileNameGuiAuthentication;
 	}
-	
-	/**
-	 * Returns DeviceStatus class. Initializes it, if necessary.
-	 * @return device status class. containing the current status data
-	 */
-	public DeviceStatus getDeviceStatus() {
-		if(deviceStatus == null) {
-			deviceStatus = new DeviceStatus(getApplicationContext(), getAppPrefs());
-		}
-		return deviceStatus;
-	}
 // --end-- public methods for Activities
     
 // multi-threaded frequent information polling
@@ -397,16 +352,7 @@ public class Monitor extends Service {
      */
     private void readClientStatus(Boolean forceCompleteUpdate) {
     	try{
-    		// read ccStatus and adjust wakelocks and service state independently of screen status
-    		// wake locks and foreground enabled when Client is not suspended, therefore also during
-    		// idle.
-    		CcStatus status = clientInterface.getCcStatus();
-    		// treat cpu throttling as if it was computing
-    		Boolean computing = (status.task_suspend_reason == BOINCDefs.SUSPEND_NOT_SUSPENDED) || (status.task_suspend_reason == BOINCDefs.SUSPEND_REASON_CPU_THROTTLE);
-    		if(Logging.VERBOSE) Log.d(Logging.TAG,"readClientStatus(): computation enabled: " + computing);
-			Monitor.getClientStatus().setWifiLock(computing);
-			Monitor.getClientStatus().setWakeLock(computing);
-			ClientNotification.getInstance(getApplicationContext()).setForeground(computing, this);
+    		CcStatus status; // read independently of screen status
     		
 			// complete status read, depending on screen status
     		// screen off: only read computing status to adjust wakelock, do not send broadcast
@@ -415,14 +361,14 @@ public class Monitor extends Service {
 	    	if(screenOn || forceCompleteUpdate) {
 	    		// complete status read, with broadcast
 				if(Logging.VERBOSE) Log.d(Logging.TAG, "readClientStatus(): screen on, get complete status");
+	    		status = clientInterface.getCcStatus();
 				CcState state = clientInterface.getState();
 				ArrayList<Transfer>  transfers = clientInterface.getFileTransfers();
 				AcctMgrInfo acctMgrInfo = clientInterface.getAcctMgrInfo();
+				ArrayList<Notice> newNotices = clientInterface.getNotices(Monitor.getClientStatus().getMostRecentNoticeSeqNo());
 				
 				if( (status != null) && (state != null) && (state.results != null) && (state.projects != null) && (transfers != null) && (state.host_info != null) && (acctMgrInfo != null)) {
-					Monitor.getClientStatus().setClientStatus(status, state.results, state.projects, transfers, state.host_info, acctMgrInfo);
-					// Update status bar notification
-					ClientNotification.getInstance(getApplicationContext()).update();
+					Monitor.getClientStatus().setClientStatus(status, state.results, state.projects, transfers, state.host_info, acctMgrInfo, newNotices);
 				} else {
 					String nullValues = "";
 					try{
@@ -436,13 +382,29 @@ public class Monitor extends Service {
 					if(Logging.ERROR) Log.e(Logging.TAG, "readClientStatus(): connection problem, null: " + nullValues);
 				}
 				
+				// update notices notification
+				NoticeNotification.getInstance(getApplicationContext()).update(Monitor.getClientStatus().getRssNotices(), Monitor.getAppPrefs().getShowNotificationForNotices());
+				
 				// check whether monitor is still intended to update, if not, skip broadcast and exit...
 				if(updateBroadcastEnabled) {
 			        Intent clientStatus = new Intent();
 			        clientStatus.setAction("edu.berkeley.boinc.clientstatus");
 			        getApplicationContext().sendBroadcast(clientStatus);
 				}
-	    	} 
+	    	} else {
+	    		// read only ccStatus to adjust wakelocks and service state independently of screen status
+	    		status = clientInterface.getCcStatus();
+	    	}
+	    	
+	    	// independent of screen on off:
+    		// wake locks and foreground enabled when Client is not suspended, therefore also during
+    		// idle.
+    		// treat cpu throttling as if it was computing.
+    		Boolean computing = (status.task_suspend_reason == BOINCDefs.SUSPEND_NOT_SUSPENDED) || (status.task_suspend_reason == BOINCDefs.SUSPEND_REASON_CPU_THROTTLE);
+    		if(Logging.VERBOSE) Log.d(Logging.TAG,"readClientStatus(): computation enabled: " + computing);
+			Monitor.getClientStatus().setWifiLock(computing);
+			Monitor.getClientStatus().setWakeLock(computing);
+			ClientNotification.getInstance(getApplicationContext()).update(Monitor.getClientStatus(), this, computing);
 			
 		}catch(Exception e) {
 			if(Logging.ERROR) Log.e(Logging.TAG, "Monitor.readClientStatus excpetion: " + e.getMessage(),e);
@@ -460,7 +422,7 @@ public class Monitor extends Service {
     	try{
 	    	// set devices status
 			if(deviceStatus != null) { // make sure deviceStatus is initialized
-				Boolean reportStatusSuccess = clientInterface.reportDeviceStatus(deviceStatus.update()); // transmit device status via rpc
+				Boolean reportStatusSuccess = clientInterface.reportDeviceStatus(deviceStatus.update(screenOn)); // transmit device status via rpc
 				if(reportStatusSuccess) screenOffStatusOmitCounter = 0;
 				else if(Logging.DEBUG) Log.d(Logging.TAG,"reporting device status returned false.");
 			} else if(Logging.WARNING) Log.w(Logging.TAG,"reporting device status failed, wrapper not initialized.");
@@ -501,7 +463,7 @@ public class Monitor extends Service {
 		// If client hashes do not match, we need to install the one that is a part
 		// of the package. Shutdown the currently running client if needed.
 		//
-		if (!md5InstalledClient.equals(md5AssetClient)) {
+		if (forceReinstall || !md5InstalledClient.equals(md5AssetClient)) {
 			if(Logging.DEBUG) Log.d(Logging.TAG,"Hashes of installed client does not match binary in assets - re-install.");
 			
 			// try graceful shutdown using RPC (faster)
@@ -561,26 +523,29 @@ public class Monitor extends Service {
 			} catch (Exception e) {}
 		}
 		
+		Boolean init = false;
 		if(connected) { // connection established
-			// make client read override settings from file
-			clientInterface.readGlobalPrefsOverride();
-			// read preferences for GUI to be able to display data
-			GlobalPreferences clientPrefs = clientInterface.getGlobalPrefsWorkingStruct();
-			status.setPrefs(clientPrefs);
-			// read supported projects
-			readAndroidProjectsList();
-			// set Android model as hostinfo
-			// should output something like "Samsung Galaxy SII - SDK:15 ABI:armeabi-v7a"
-			String model = Build.MANUFACTURER + " " + Build.MODEL + " - SDK:" + Build.VERSION.SDK_INT + " ABI: " + Build.CPU_ABI;
-			if(Logging.DEBUG) Log.d(Logging.TAG,"reporting hostinfo model name: " + model);
-			clientInterface.setHostInfo(model);
+			try {
+				// read preferences for GUI to be able to display data
+				GlobalPreferences clientPrefs = clientInterface.getGlobalPrefsWorkingStruct();
+				if(clientPrefs == null) throw new Exception("client prefs null");
+				status.setPrefs(clientPrefs);
+				
+				// set Android model as hostinfo
+				// should output something like "Samsung Galaxy SII - SDK:15 ABI:armeabi-v7a"
+				String model = Build.MANUFACTURER + " " + Build.MODEL + " - SDK:" + Build.VERSION.SDK_INT + " ABI: " + Build.CPU_ABI;
+				if(Logging.DEBUG) Log.d(Logging.TAG,"reporting hostinfo model name: " + model);
+				clientInterface.setHostInfo(model);
+				
+				init = true;
+			} catch(Exception e) {if(Logging.ERROR) Log.e(Logging.TAG,"Monitor.clientSetup() init failed: " + e.getMessage());}
 		}
 		
-		if(connected) {
+		if(init) {
 			if(Logging.DEBUG) Log.d(Logging.TAG, "setup completed successfully"); 
 			status.setSetupStatus(ClientStatus.SETUP_STATUS_AVAILABLE,false);
 		} else {
-			if(Logging.DEBUG) Log.d(Logging.TAG, "onPostExecute - setup experienced an error"); 
+			if(Logging.ERROR) Log.e(Logging.TAG, "onPostExecute - setup experienced an error"); 
 			status.setSetupStatus(ClientStatus.SETUP_STATUS_ERROR,true);
 		}
 		
@@ -595,10 +560,11 @@ public class Monitor extends Service {
     private Boolean runClient() {
     	Boolean success = false;
     	try { 
-    		String[] cmd = new String[2];
+    		String[] cmd = new String[3];
     		
     		cmd[0] = boincWorkingDir + fileNameClient;
     		cmd[1] = "--daemon";
+    		cmd[2] = "--gui_rpc_unix_domain";
     		
         	Runtime.getRuntime().exec(cmd, null, new File(boincWorkingDir));
         	success = true;
@@ -616,16 +582,16 @@ public class Monitor extends Service {
 	private Boolean connectClient() {
 		Boolean success = false;
 		
-        success = clientInterface.connect();
+        success = clientInterface.open(clientSocketAddress);
         if(!success) {
-        	if(Logging.DEBUG) Log.d(Logging.TAG, "connection failed!");
+        	if(Logging.ERROR) Log.e(Logging.TAG, "connection failed!");
         	return success;
         }
         
         //authorize
         success = clientInterface.authorizeGuiFromFile(boincWorkingDir + fileNameGuiAuthentication);
         if(!success) {
-        	if(Logging.DEBUG) Log.d(Logging.TAG, "authorization failed!");
+        	if(Logging.ERROR) Log.e(Logging.TAG, "authorization failed!");
         }
         return success;
 	}
@@ -887,7 +853,7 @@ public class Monitor extends Service {
     }
 // --end-- BOINC client installation and run-time management
 	
-// screen on/off receiver
+// broadcast receiver
 	/**
 	 * broadcast receiver to detect changes to screen on or off, used to adapt scheduling of StatusUpdateTimerTask
 	 * e.g. avoid polling GUI status RPCs while screen is off in order to save battery
@@ -898,6 +864,9 @@ public class Monitor extends Service {
 			String action = intent.getAction();
 			if(action.equals(Intent.ACTION_SCREEN_OFF)) {
 				screenOn = false;
+				// forces report of device status at next scheduled update
+				// allows timely reaction to screen off for resume of computation
+				screenOffStatusOmitCounter = deviceStatusIntervalScreenOff;
 				if(Logging.DEBUG) Log.d(Logging.TAG, "screenOnOffReceiver: screen turned off");
 			}
 			if(action.equals(Intent.ACTION_SCREEN_ON)) {
@@ -907,5 +876,382 @@ public class Monitor extends Service {
 			}
         } 
 	}; 
-// --end-- screen on/off receiver
+// --end-- broadcast receiver
+	
+// async tasks
+	private final class SetClientRunModeAsync extends AsyncTask<Integer, Void, Void> {
+		@Override
+		protected Void doInBackground(Integer... params) {
+			try {
+				mBinder.setRunMode(params[0]);
+			} catch (RemoteException e) {}
+			return null;
+		}
+	}
+// --end -- async tasks
+	
+// remote service
+	private final IMonitor.Stub mBinder = new IMonitor.Stub() {
+			
+		@Override
+		public boolean transferOperation(List<Transfer> list, int op) throws RemoteException {
+			return clientInterface.transferOperation((ArrayList<Transfer>)list, op);
+		}
+		
+		@Override
+		public boolean synchronizeAcctMgr(String url) throws RemoteException {
+			return clientInterface.synchronizeAcctMgr(url);
+		}
+		
+		@Override
+		public boolean setRunMode(int mode) throws RemoteException {
+			return clientInterface.setRunMode(mode);
+		}
+		
+		@Override
+		public boolean setNetworkMode(int mode) throws RemoteException {
+			return clientInterface.setNetworkMode(mode);
+		}
+		
+		@Override
+		public boolean setGlobalPreferences(GlobalPreferences pref)
+				throws RemoteException {
+			return clientInterface.setGlobalPreferences(pref);
+		}
+		
+		@Override
+		public boolean setCcConfig(String config) throws RemoteException {
+			return clientInterface.setCcConfig(config);
+		}
+		
+		@Override
+		public boolean resultOp(int op, String url, String name)
+				throws RemoteException {
+			return clientInterface.resultOp(op, url, name);
+		}
+		
+		@Override
+		public String readAuthToken(String path) throws RemoteException {
+			return clientInterface.readAuthToken(path);
+		}
+		
+		@Override
+		public boolean projectOp(int status, String url) throws RemoteException {
+			return clientInterface.projectOp(status, url);
+		}
+		
+		@Override
+		public int getBoincPlatform() throws RemoteException {
+			return Monitor.this.getBoincPlatform();
+		}
+		
+		@Override
+		public AccountOut lookupCredentials(AccountIn credentials) throws RemoteException {
+			return clientInterface.lookupCredentials(credentials);
+		}
+		
+		@Override
+		public boolean isStationaryDeviceSuspected() throws RemoteException {
+			try {
+				return Monitor.getDeviceStatus().isStationaryDeviceSuspected();
+			} catch (Exception e) {}
+			return false;
+		}
+		
+		@Override
+		public List<Notice> getServerNotices() throws RemoteException {
+			return clientStatus.getServerNotices();
+		}
+		
+		@Override
+		public ProjectConfig getProjectConfigPolling(String url)
+				throws RemoteException {
+			return clientInterface.getProjectConfigPolling(url);
+		}
+		
+		@Override
+		public List<Notice> getNotices(int seq) throws RemoteException {
+			return clientInterface.getNotices(seq);
+		}
+		
+		@Override
+		public List<Message> getMessages(int seq) throws RemoteException {
+			return clientInterface.getMessages(seq);
+		}
+		
+		@Override
+		public List<Message> getEventLogMessages(int seq, int num)
+				throws RemoteException {
+			return clientInterface.getEventLogMessages(seq, num);
+		}
+		
+		@Override
+		public int getBatteryChargeStatus() throws RemoteException{
+			try {
+				return getDeviceStatus().getStatus().battery_charge_pct;
+			} catch (Exception e) {}
+			return 0;
+		}
+		
+		@Override
+		public AcctMgrInfo getAcctMgrInfo() throws RemoteException {
+			return clientInterface.getAcctMgrInfo();
+		}
+		
+		@Override
+		public void forceRefresh() throws RemoteException {
+			Monitor.this.forceRefresh();
+		}
+		
+		@Override
+		public AccountOut createAccountPolling(AccountIn information) throws RemoteException {
+			return clientInterface.createAccountPolling(information);
+		}
+		
+		@Override
+		public boolean checkProjectAttached(String url) throws RemoteException {
+			return clientInterface.checkProjectAttached(url);
+		}
+		
+		@Override
+		public boolean attachProject(String url, String projectName, String authenticator)
+				throws RemoteException {
+			return clientInterface.attachProject(url, projectName, authenticator);
+		}
+		
+		@Override
+		public int addAcctMgrErrorNum(String url, String userName, String pwd)
+				throws RemoteException {
+			AcctMgrRPCReply acctMgr =clientInterface.addAcctMgr(url, userName, pwd);
+			if (acctMgr!=null) {
+				return acctMgr.error_num;
+			}
+			return -1;
+		}
+		
+		@Override
+		public String getAuthFilePath() throws RemoteException {
+			return Monitor.this.getAuthFilePath();
+		}
+		
+		@Override
+		public List<ProjectInfo> getAttachableProjects() throws RemoteException {
+			return clientInterface.getAttachableProjects(getString(getBoincPlatform()));
+		}
+		
+		@Override
+		public boolean getAcctMgrInfoPresent() throws RemoteException {
+			return clientStatus.getAcctMgrInfo().present;
+		}
+		
+		@Override
+		public int getSetupStatus() throws RemoteException {
+			return clientStatus.setupStatus;
+		}
+		
+		@Override
+		public int getComputingStatus() throws RemoteException {
+			return clientStatus.computingStatus;
+		}
+		
+		@Override
+		public int getComputingSuspendReason() throws RemoteException {
+			return clientStatus.computingSuspendReason;
+		}
+		
+		@Override
+		public int getNetworkSuspendReason() throws RemoteException {
+			return clientStatus.networkSuspendReason;
+		}
+		
+		@Override
+		public HostInfo getHostInfo() throws RemoteException {
+			return clientStatus.getHostInfo();
+		}
+		
+		@Override
+		public GlobalPreferences getPrefs() throws RemoteException {
+			return clientStatus.getPrefs();
+		}
+		
+		@Override
+		public List<Project> getProjects() throws RemoteException {
+			return clientStatus.getProjects();
+		}
+		
+		@Override
+		public AcctMgrInfo getClientAcctMgrInfo() throws RemoteException {
+			return clientStatus.getAcctMgrInfo();
+		}
+		
+		@Override
+		public List<Transfer> getTransfers() throws RemoteException {
+			return clientStatus.getTransfers();
+		}
+		
+		@Override
+		public void setAutostart(boolean isAutoStart) throws RemoteException {
+			Monitor.getAppPrefs().setAutostart(isAutoStart);
+		}
+		
+		@Override
+		public void setShowNotificationForNotices(boolean isShow) throws RemoteException {
+			Monitor.getAppPrefs().setShowNotificationForNotices(isShow);
+		}
+		
+		@Override
+		public boolean getShowAdvanced() throws RemoteException {
+			return Monitor.getAppPrefs().getShowAdvanced();
+		}
+		
+		@Override
+		public boolean getAutostart() throws RemoteException {
+			return Monitor.getAppPrefs().getAutostart();
+		}
+		
+		@Override
+		public boolean getShowNotificationForNotices() throws RemoteException {
+			return  Monitor.getAppPrefs().getShowNotificationForNotices();
+		}
+		
+		@Override
+		public int getLogLevel() throws RemoteException {
+			return Monitor.getAppPrefs().getLogLevel();
+		}
+		
+		@Override
+		public void setLogLevel(int level) throws RemoteException {
+			Monitor.getAppPrefs().setLogLevel(level);
+		}
+		
+		@Override
+		public void setPowerSourceAc(boolean src) throws RemoteException {
+			Monitor.getAppPrefs().setPowerSourceAc(src);
+		}
+		
+		@Override
+		public void setPowerSourceUsb(boolean src) throws RemoteException {
+			Monitor.getAppPrefs().setPowerSourceUsb(src);
+		}
+		
+		@Override
+		public void setPowerSourceWireless(boolean src) throws RemoteException {
+			Monitor.getAppPrefs().setPowerSourceWireless(src);
+		}
+		
+		@Override
+		public List<Result> getTasks() throws RemoteException {
+			return clientStatus.getTasks();
+		}
+		
+		@Override
+		public String getProjectStatus(String url) throws RemoteException {
+			return clientStatus.getProjectStatus(url);
+		}
+		
+		@Override
+		public List<Notice> getRssNotices() throws RemoteException {
+			return clientStatus.getRssNotices();
+		}
+		
+		@Override
+		public List<ImageWrapper> getSlideshowForProject(String url)
+				throws RemoteException {
+			return clientStatus.getSlideshowForProject(url);
+		}
+		
+		@Override
+		public boolean getStationaryDeviceMode() throws RemoteException {
+			return Monitor.getAppPrefs().getStationaryDeviceMode();
+		}
+		
+		@Override
+		public boolean getPowerSourceAc() throws RemoteException {
+			return Monitor.getAppPrefs().getPowerSourceAc();
+		}
+		
+		@Override
+		public boolean getPowerSourceUsb() throws RemoteException {
+			return Monitor.getAppPrefs().getPowerSourceUsb();
+		}
+		
+		@Override
+		public boolean getPowerSourceWireless() throws RemoteException {
+			return Monitor.getAppPrefs().getPowerSourceWireless();
+		}
+		
+		@Override
+		public void setShowAdvanced(boolean isShow) throws RemoteException {
+			Monitor.getAppPrefs().setShowAdvanced(isShow);
+		}
+		
+		@Override
+		public void setStationaryDeviceMode(boolean mode)
+				throws RemoteException {
+			Monitor.getAppPrefs().setStationaryDeviceMode(mode);
+			
+		}
+		
+		@Override
+		public Bitmap getProjectIconByName(String name) throws RemoteException {
+			return clientStatus.getProjectIconByName(name);
+		}
+		
+		@Override
+		public Bitmap getProjectIcon(String id) throws RemoteException {
+			return clientStatus.getProjectIcon(id);
+		}
+
+		@Override
+		public boolean getSuspendWhenScreenOn() throws RemoteException {
+			return Monitor.getAppPrefs().getSuspendWhenScreenOn();
+		}
+
+		@Override
+		public void setSuspendWhenScreenOn(boolean swso) throws RemoteException {
+			Monitor.getAppPrefs().setSuspendWhenScreenOn(swso);
+		}
+
+		@Override
+		public String getCurrentStatusTitle() throws RemoteException {
+			return clientStatus.getCurrentStatusTitle();
+		}
+
+		@Override
+		public String getCurrentStatusDescription() throws RemoteException {
+			return clientStatus.getCurrentStatusDescription();
+		}
+
+		@Override
+		public void cancelNoticeNotification() throws RemoteException {
+			NoticeNotification.getInstance(getApplicationContext()).cancelNotification();
+		}
+
+		@Override
+		public void setShowNotificationDuringSuspend(boolean isShow) throws RemoteException {
+			Monitor.getAppPrefs().setShowNotificationDuringSuspend(isShow);
+			
+		}
+
+		@Override
+		public boolean getShowNotificationDuringSuspend() throws RemoteException {
+			return Monitor.getAppPrefs().getShowNotificationDuringSuspend();
+		}
+
+		@Override
+		public boolean runBenchmarks() throws RemoteException {
+			return clientInterface.runBenchmarks();
+		}
+
+		@Override
+		public ProjectInfo getProjectInfo(String url) throws RemoteException {
+			return clientInterface.getProjectInfo(url);
+		}
+
+		@Override
+		public boolean boincMutexAcquired() throws RemoteException {
+			return mutex.acquired;
+		}
+	};
+// --end-- remote service	
 }
