@@ -24,14 +24,14 @@ import java.io.IOException;
 import java.io.InputStream;
 import java.io.OutputStreamWriter;
 import java.io.StringReader;
-import java.net.InetSocketAddress;
-import java.net.Socket;
-import java.net.UnknownHostException;
 import java.util.ArrayList;
 import java.util.Locale;
 
 import org.xml.sax.SAXException;
 import org.xml.sax.helpers.DefaultHandler;
+
+import android.net.LocalSocket;
+import android.net.LocalSocketAddress;
 import android.util.Log;
 import android.util.Xml;
 import edu.berkeley.boinc.utils.BOINCDefs;
@@ -47,7 +47,6 @@ import edu.berkeley.boinc.utils.Logging;
  * get_cc_status() becomes getCcStatus() etc.
  */
 public class RpcClient {
-	private static final int CONNECT_TIMEOUT = 30000;      // 30s
 	private static final int READ_TIMEOUT = 15000;         // 15s
 	private static final int READ_BUF_SIZE = 2048;
 	private static final int RESULT_BUILDER_INIT_SIZE = 131072; // Yes, 128K
@@ -75,7 +74,7 @@ public class RpcClient {
 	public static final int MGR_DETACH = 30;
 	public static final int MGR_SYNC = 31;
 	
-	private Socket mSocket;
+	private LocalSocket mSocket;
 	private OutputStreamWriter mOutput;
 	private InputStream mInput;
 	private byte[] mReadBuffer = new byte[READ_BUF_SIZE];
@@ -159,12 +158,10 @@ public class RpcClient {
 	 */
 
 	/**
-	 * Connect to BOINC core client
-	 * @param address Internet address of client (hostname or IP-address)
-	 * @param port Port of BOINC client (default port is 31416)
+	 * Connect to BOINC core client via Unix Domain Socket (abstract, "boinc_socket")
 	 * @return true for success, false for failure
 	 */
-	public boolean open(String address, int port) {
+	public boolean open(String socketAddress) {
 		if (isConnected()) {
 			// Already connected
 			if(edu.berkeley.boinc.utils.Logging.LOGLEVEL <= 4) Log.e(Logging.TAG, "Attempt to connect when already connected");
@@ -172,17 +169,12 @@ public class RpcClient {
 			close();
 		}
 		try {
-			mSocket = new Socket();
-			mSocket.connect(new InetSocketAddress(address, port), CONNECT_TIMEOUT);
+			mSocket = new LocalSocket();
+			mSocket.connect(new LocalSocketAddress(socketAddress));
 			mSocket.setSoTimeout(READ_TIMEOUT);
 			mInput = mSocket.getInputStream();
 			mOutput = new OutputStreamWriter(mSocket.getOutputStream(), "ISO8859_1");
 		}
-		catch (UnknownHostException e) {
-			if(Logging.WARNING) Log.w(Logging.TAG, "connect failure: unknown host \"" + address + "\"", e);
-			mSocket = null;
-			return false;
-		}
 		catch (IllegalArgumentException e) {
 			if(edu.berkeley.boinc.utils.Logging.LOGLEVEL <= 4) Log.e(Logging.TAG, "connect failure: illegal argument", e);
 			mSocket = null;
@@ -193,7 +185,12 @@ public class RpcClient {
 			mSocket = null;
 			return false;
 		}
-		if(Logging.DEBUG) Log.d(Logging.TAG, "open(" + address + ", " + port + ") - Connected successfully");
+		catch (Exception e) {
+			if(Logging.WARNING) Log.w(Logging.TAG, "connect failure", e);
+			mSocket = null;
+			return false;
+		}
+		if(Logging.DEBUG) Log.d(Logging.TAG, "Connected successfully");
 		return true;
 	}
 
@@ -242,6 +239,7 @@ public class RpcClient {
 		if (!isConnected()) {
 			return false;
 		}
+		if(password.length() == 0) return false;
 		try {
 			// Phase 1: get nonce
 			sendRequest("<auth1/>\n");
@@ -423,6 +421,7 @@ public class RpcClient {
 		}
 		catch (IOException e) {
 			if(Logging.WARNING) Log.w(Logging.TAG, "error in getCcStatus()", e);
+			e.printStackTrace();
 			return null;
 		}
 	}
@@ -502,7 +501,6 @@ public class RpcClient {
 			}
 			sendRequest(request);
 			ArrayList<Message> messages = MessagesParser.parse(receiveReply());
-			if(messages == null) messages = new ArrayList<Message>(); // do not return null
 			return messages;
 		}
 		catch (IOException e) {
@@ -816,7 +814,7 @@ public class RpcClient {
 	public synchronized boolean lookupAccount(AccountIn accountIn) {
 		try {
 			String id;
-			if(accountIn.email_addr == null || accountIn.email_addr.isEmpty()) id = accountIn.user_name;
+			if(accountIn.uses_name) id = accountIn.user_name;
 			else id = accountIn.email_addr;
 			mRequest.setLength(0);
 			mRequest.append("<lookup_account>\n <url>");
@@ -1394,4 +1392,22 @@ public class RpcClient {
 			return false;
 		}
 	}
+	
+	public synchronized Boolean runBenchmarks() {
+		try {
+			mRequest.setLength(0);
+			mRequest.append("<run_benchmarks/>");
+
+			sendRequest(mRequest.toString());
+			SimpleReplyParser parser = SimpleReplyParser.parse(receiveReply());
+			if (parser == null)
+				return false;
+			mLastErrorMessage = parser.getErrorMessage();
+			return parser.result();
+		} catch (IOException e) {
+			if(Logging.WARNING) Log.w(Logging.TAG, "error in runBenchmark()", e);
+			return false;
+		}
+		
+	}
 }
