@@ -142,7 +142,9 @@ extern int boinc_report_app_status_aux(
     double cpu_time, double checkpoint_cpu_time, double _fraction_done,
     int other_pid, double bytes_sent, double bytes_received
 );
-extern int boinc_temporary_exit(int delay, const char* reason=NULL);
+extern int boinc_temporary_exit(
+    int delay, const char* reason=NULL, bool is_notice=false
+);
 
 /////////// API ENDS HERE
 
