@@ -105,7 +105,7 @@ bool ACTIVE_TASK_SET::poll() {
                         atp->result->name
                     );
                 }
-                atp->kill_task(false);
+                atp->kill_running_task(false);
             }
         }
         if (atp->task_state() == PROCESS_QUIT_PENDING) {
@@ -116,7 +116,7 @@ bool ACTIVE_TASK_SET::poll() {
                         atp->result->name
                     );
                 }
-                atp->kill_task(true);
+                atp->kill_running_task(true);
             }
         }
     }
@@ -211,29 +211,34 @@ int ACTIVE_TASK::request_abort() {
 
 #ifdef _WIN32
 static void kill_app_process(int pid, bool will_restart) {
-    HANDLE h = OpenProcess(READ_CONTROL | PROCESS_TERMINATE, false, pid);
-    if (h == NULL) return;
-    TerminateProcess(h, will_restart?0:EXIT_ABORTED_BY_CLIENT);
-    CloseHandle(h);
+    int retval = 0;
+    retval = kill_program(pid, will_restart?0:EXIT_ABORTED_BY_CLIENT);
+    if (retval && log_flags.task_debug) {
+        msg_printf(0, MSG_INFO,
+            "[task] kill_app_process() failed: %s",
+            strerror(retval)
+        );
+    }
 }
 #else
 static void kill_app_process(int pid, bool) {
     int retval = 0;
-#ifdef SANDBOX
-    retval = kill_via_switcher(pid);
-    if (retval && log_flags.task_debug) {
-        msg_printf(0, MSG_INFO,
-            "[task] kill_via_switcher() failed: %s",
-            boincerror(retval)
-        );
-    }
-#endif
-    retval = kill(pid, SIGKILL);
-    if (retval && log_flags.task_debug) {
-        msg_printf(0, MSG_INFO,
-            "[task] kill() failed: %s",
-            boincerror(retval)
-        );
+    if (g_use_sandbox) {
+        retval = kill_via_switcher(pid);
+        if (retval && log_flags.task_debug) {
+            msg_printf(0, MSG_INFO,
+                "[task] kill_via_switcher() failed: %s (%d)",
+                (retval>=0) ? strerror(errno) : boincerror(retval), retval
+            );
+        }
+    } else {
+        retval = kill(pid, SIGKILL);
+        if (retval && log_flags.task_debug) {
+            msg_printf(0, MSG_INFO,
+                "[task] kill() failed: %s",
+                strerror(errno)
+            );
+        }
     }
 }
 #endif
@@ -244,27 +249,24 @@ static inline void kill_processes(vector<int> pids, bool will_restart) {
     }
 }
 
-// Kill the task (and descendants) by OS-specific means.
+// Kill a task whose main process is still running
+// Just kill the main process; shared mem and subsidiary processes
+// will be cleaned up after it exits, by cleanup_task();
 //
-int ACTIVE_TASK::kill_task(bool will_restart) {
-    vector<int>pids;
-#ifdef _WIN32
-    // On Win, in protected mode we won't be able to get
-    // handles for the descendant processes;
-    // all we can do is terminate the main process,
-    // using the handle we got when we created it.
-    //
-    if (g_use_sandbox) {
-        TerminateProcess(process_handle, will_restart?0:EXIT_ABORTED_BY_CLIENT);
-        return 0;
-    }
-#endif
-    get_descendants(pid, pids);
-    pids.push_back(pid);
-    for (unsigned int i=0; i<other_pids.size(); i++) {
-        pids.push_back(other_pids[i]);
-    }
-    kill_processes(pids, will_restart);
+int ACTIVE_TASK::kill_running_task(bool will_restart) {
+    kill_app_process(pid, will_restart);
+    return 0;
+}
+
+// Clean up the subsidiary processes of a task whose main process has exited,
+// namely:
+// - its descendants (as recently enumerated; it's too late to do that now)
+//   This list will be populated only in the quit and abort cases.
+// - its "other" processes, e.g. VMs
+//
+int ACTIVE_TASK::kill_subsidiary_processes() {
+    kill_processes(other_pids, true);
+    kill_processes(descendants, true);
     return 0;
 }
 
@@ -430,10 +432,8 @@ void ACTIVE_TASK::handle_exited_app(int stat) {
     //
     if (task_state() == PROCESS_ABORT_PENDING) {
         set_task_state(PROCESS_ABORTED, "handle_exited_app");
-        kill_processes(descendants, false);
     } else if (task_state() == PROCESS_QUIT_PENDING) {
         set_task_state(PROCESS_UNINITIALIZED, "handle_exited_app");
-        kill_processes(descendants, true);
         will_restart = true;
     } else {
 #ifdef _WIN32
@@ -562,6 +562,8 @@ void ACTIVE_TASK::handle_exited_app(int stat) {
 #endif
     }
 
+    // get rid of shared-mem segment and kill subsidiary processes
+    //
     cleanup_task();
 
     if (gstate.run_test_app) {
@@ -694,7 +696,7 @@ void ACTIVE_TASK_SET::process_control_poll() {
                     "Restarting %s - message timeout", atp->result->name
                 );
             }
-            atp->kill_task(true);
+            atp->kill_running_task(true);
         } else {
             atp->process_control_queue.msg_queue_poll(
                 atp->app_client_shm.shm->process_control_request
@@ -737,6 +739,7 @@ bool ACTIVE_TASK_SET::check_app_exited() {
             // The process doesn't seem to be there.
             // Mark task as aborted so we don't check it again.
             //
+            atp->cleanup_task();
             atp->set_task_state(PROCESS_ABORTED, "check_app_exited");
         }
     }
@@ -1241,7 +1244,7 @@ void ACTIVE_TASK_SET::kill_tasks(PROJECT* proj) {
         atp = active_tasks[i];
         if (proj && atp->wup->project != proj) continue;
         if (!atp->process_exists()) continue;
-        atp->kill_task(true);
+        atp->kill_running_task(true);
     }
 }
 
@@ -1468,7 +1471,9 @@ void ACTIVE_TASK_SET::get_msgs() {
         if (!atp->process_exists()) continue;
         old_time = atp->checkpoint_cpu_time;
         if (atp->scheduler_state == CPU_SCHED_SCHEDULED) {
-            atp->elapsed_time += atp->result->dont_throttle()?et_diff:et_diff_throttle;
+            double x = atp->result->dont_throttle()?et_diff:et_diff_throttle;
+            atp->elapsed_time += x;
+            atp->wup->project->elapsed_time += x;
         }
         if (atp->get_app_status_msg()) {
             if (old_time != atp->checkpoint_cpu_time) {
