@@ -345,9 +345,12 @@ bool NOTICES::remove_dups(NOTICE& n) {
         ) {
             i = notices.erase(i);
             removed_something = true;
+#if 0
+        // this check prevents news item edits from showing; skip it
         } else if (same_guid(n, n2)) {
             n2.keep = true;
             return false;
+#endif
         } else if (same_text(n, n2)) {
             int min_diff = 0;
 
@@ -509,6 +512,9 @@ void NOTICES::remove_notices(PROJECT* p, int which) {
         case REMOVE_APP_INFO_MSG:
             remove = (strstr(n.description.c_str(), "app_info.xml") != NULL);
             break;
+        case REMOVE_APP_CONFIG_MSG:
+            remove = (strstr(n.description.c_str(), "app_config.xml") != NULL);
+            break;
         }
         if (remove) {
             i = notices.erase(i);
