@@ -207,7 +207,7 @@ int CLIENT_STATE::check_suspend_processing() {
         return SUSPEND_REASON_BENCHMARKS;
     }
 
-    if (config.start_delay && now < time_stats.client_start_time + config.start_delay) {
+    if (cc_config.start_delay && now < time_stats.client_start_time + cc_config.start_delay) {
         return SUSPEND_REASON_INITIAL_DELAY;
     }
 
@@ -227,9 +227,12 @@ int CLIENT_STATE::check_suspend_processing() {
         ) {
             return SUSPEND_REASON_BATTERIES;
         }
+#ifndef ANDROID
+        // perform this check after SUSPEND_REASON_BATTERY_CHARGING on Android
         if (!global_prefs.run_if_user_active && user_active) {
             return SUSPEND_REASON_USER_ACTIVE;
         }
+#endif
         if (global_prefs.cpu_times.suspended(now)) {
             return SUSPEND_REASON_TIME_OF_DAY;
         }
@@ -251,6 +254,7 @@ int CLIENT_STATE::check_suspend_processing() {
 
 #ifdef ANDROID
     if (now > device_status_time + ANDROID_KEEPALIVE_TIMEOUT) {
+        requested_exit = true;
         return SUSPEND_REASON_NO_GUI_KEEPALIVE;
     }
 
@@ -273,8 +277,19 @@ int CLIENT_STATE::check_suspend_processing() {
             return SUSPEND_REASON_BATTERY_CHARGING;
         }
     }
+    
+    // user active.
+    // Do this check after checks that user can not influence on Android.
+    // E.g.
+    // 1. "connect to charger to continue computing"
+    // 2. "charge battery until 90%"
+    // 3. "turn screen off to continue computing"
+    if (!global_prefs.run_if_user_active && user_active) {
+        return SUSPEND_REASON_USER_ACTIVE;
+    }
 #endif
 
+#ifndef NEW_CPU_THROTTLE
     // CPU throttling.
     // Do this check last; that way if suspend_reason is CPU_THROTTLE,
     // the GUI knows there's no other source of suspension
@@ -292,6 +307,7 @@ int CLIENT_STATE::check_suspend_processing() {
             }
         }
     }
+#endif
 
     // CPU is not suspended.  See if GPUs are
     //
@@ -334,11 +350,7 @@ int CLIENT_STATE::check_suspend_processing() {
 }
 
 void CLIENT_STATE::show_suspend_tasks_message(int reason) {
-    if (reason == SUSPEND_REASON_CPU_THROTTLE) {
-        if (log_flags.cpu_sched) {
-            msg_printf(NULL, MSG_INFO, "[cpu_sched] Suspending - CPU throttle");
-        }
-    } else {
+    if (reason != SUSPEND_REASON_CPU_THROTTLE) {
         if (log_flags.task) {
             msg_printf(NULL, MSG_INFO,
                 "Suspending computation - %s",
@@ -370,10 +382,7 @@ void CLIENT_STATE::show_suspend_tasks_message(int reason) {
 
 int CLIENT_STATE::resume_tasks(int reason) {
     if (reason == SUSPEND_REASON_CPU_THROTTLE) {
-        if (log_flags.cpu_sched) {
-            msg_printf(NULL, MSG_INFO, "[cpu_sched] Resuming - CPU throttle");
-        }
-        active_tasks.unsuspend_all();
+        active_tasks.unsuspend_all(SUSPEND_REASON_CPU_THROTTLE);
     } else {
         if (log_flags.task) {
             msg_printf(NULL, MSG_INFO, "Resuming computation");
@@ -402,7 +411,7 @@ void CLIENT_STATE::check_suspend_network() {
 
     // no network traffic if we're allowing unsigned apps
     //
-    if (config.unsigned_apps_ok) {
+    if (cc_config.unsigned_apps_ok) {
         network_suspended = true;
         file_xfers_suspended = true;
         network_suspend_reason = SUSPEND_REASON_USER_REQ;
@@ -427,6 +436,7 @@ void CLIENT_STATE::check_suspend_network() {
 
 #ifdef ANDROID
     if (now > device_status_time + ANDROID_KEEPALIVE_TIMEOUT) {
+        requested_exit = true;
         file_xfers_suspended = true;
         if (!recent_rpc) network_suspended = true;
         network_suspend_reason = SUSPEND_REASON_NO_GUI_KEEPALIVE;
@@ -452,11 +462,15 @@ void CLIENT_STATE::check_suspend_network() {
         }
     }
 
+#ifndef ANDROID
+// allow network transfers while user active, i.e. screen on.
+// otherwise nothing (visible to the user) happens after intial attach
     if (!global_prefs.run_if_user_active && user_active) {
         file_xfers_suspended = true;
         if (!recent_rpc) network_suspended = true;
         network_suspend_reason = SUSPEND_REASON_USER_ACTIVE;
     }
+#endif    
     if (global_prefs.net_times.suspended(now)) {
         file_xfers_suspended = true;
         if (!recent_rpc) network_suspended = true;
