@@ -117,7 +117,6 @@ int CLIENT_STATE::parse_state_file_aux(const char* fname) {
     PROJECT *project=NULL;
     int retval=0;
     int failnum;
-    bool btemp;
     string stemp;
 
     FILE* f = fopen(fname, "r");
@@ -475,11 +474,7 @@ int CLIENT_STATE::parse_state_file_aux(const char* fname) {
         if (xp.parse_int("core_client_release", old_release)) {
             continue;
         }
-		if (xp.parse_str("language", language, sizeof(language))) {
-			continue;
-		}
-        if (xp.parse_bool("cpu_benchmarks_pending", btemp)) {
-            if (btemp) run_cpu_benchmarks = true;
+        if (xp.parse_str("language", language, sizeof(language))) {
             continue;
         }
         if (xp.match_tag("proxy_info")) {
@@ -755,7 +750,6 @@ int CLIENT_STATE::write_state(MIOFILE& f) {
         "<user_gpu_request>%d</user_gpu_request>\n"
         "<user_gpu_prev_request>%d</user_gpu_prev_request>\n"
         "<user_network_request>%d</user_network_request>\n"
-        "%s"
         "<new_version_check_time>%f</new_version_check_time>\n"
         "<all_projects_list_check_time>%f</all_projects_list_check_time>\n",
         get_primary_platform(),
@@ -767,13 +761,12 @@ int CLIENT_STATE::write_state(MIOFILE& f) {
         gpu_run_mode.get_perm(),
         gpu_run_mode.get_prev(),
         network_run_mode.get_perm(),
-        cpu_benchmarks_pending?"<cpu_benchmarks_pending/>\n":"",
         new_version_check_time,
         all_projects_list_check_time
     );
-	if (strlen(language)) {
-		f.printf("<language>%s</language>\n", language);
-	}
+    if (strlen(language)) {
+        f.printf("<language>%s</language>\n", language);
+    }
     if (newer_version.size()) {
         f.printf("<newer_version>%s</newer_version>\n", newer_version.c_str());
     }
@@ -848,7 +841,10 @@ int CLIENT_STATE::parse_app_info(PROJECT* p, FILE* in) {
 
     while (!xp.get_tag()) {
         if (xp.match_tag("app_info")) continue;
-        if (xp.match_tag("/app_info")) return 0;
+        if (xp.match_tag("/app_info")) {
+            notices.remove_notices(p, REMOVE_APP_INFO_MSG);
+            return 0;
+        }
         if (xp.match_tag("file_info") || xp.match_tag("file")) {
             FILE_INFO* fip = new FILE_INFO;
             if (fip->parse(xp)) {
