@@ -25,6 +25,7 @@
 #else
 #include "config.h"
 #include <cstdio>
+#include <cstddef>
 #if HAVE_UNISTD_H
 #include <unistd.h>
 #endif
@@ -35,9 +36,7 @@
 #if HAVE_SYS_STAT_H
 #include <sys/stat.h>
 #endif
-#if HAVE_SYS_UN_H
 #include <sys/un.h>
-#endif
 #include <vector>
 #include <cstring>
 #if HAVE_NETINET_IN_H
@@ -138,7 +137,7 @@ void GUI_RPC_CONN_SET::get_password() {
     //
     retval = make_random_string(password);
     if (retval) {
-        if (config.os_random_only) {
+        if (cc_config.os_random_only) {
             msg_printf(
                 NULL, MSG_INTERNAL_ERROR,
                 "OS random string generation failed, exiting"
@@ -224,13 +223,61 @@ int GUI_RPC_CONN_SET::insert(GUI_RPC_CONN* p) {
     return 0;
 }
 
+int GUI_RPC_CONN_SET::init_unix_domain() {
+#if !defined(_WIN32)
+    struct sockaddr_un addr;
+    get_password();
+    int retval = boinc_socket(lsock, AF_UNIX);
+    if (retval) {
+        msg_printf(NULL, MSG_INTERNAL_ERROR,
+            "Failed to create Unix domain socket: %s", boincerror(retval)
+        );
+        return retval;
+    }
+    addr.sun_family = AF_UNIX;
+#ifdef ANDROID
+    // bind socket in abstract address space, i.e. start with 0 byte
+    addr.sun_path[0] = '\0';
+    // using app specific socket name instead of GUI_RPC_FILE defintion
+    // to avoid interference with other BOINC based Android apps.
+    strcpy(&addr.sun_path[1], "edu_berkeley_boinc_client_socket");
+    socklen_t len = offsetof(struct sockaddr_un, sun_path) + 1 + strlen(&addr.sun_path[1]);
+#else
+    // NOTE: if we ever add Mac OS X support, need to change this
+    //
+#ifdef __APPLE__
+    addr.sun_len = sizeof(addr);
+#endif
+    strcpy(addr.sun_path, GUI_RPC_FILE);
+    socklen_t len = offsetof(sockaddr_un, sun_path) + strlen(GUI_RPC_FILE);
+#endif
+    unlink(GUI_RPC_FILE);
+    if (bind(lsock, (struct sockaddr*)&addr, len) < 0) {
+        msg_printf(NULL, MSG_INTERNAL_ERROR,
+            "Failed to bind Unix domain socket"
+        );
+        boinc_close_socket(lsock);
+        return ERR_BIND;
+    }
+    retval = listen(lsock, 999);
+    if (retval < 0) {
+        msg_printf(NULL, MSG_INTERNAL_ERROR,
+            "Failed to listen on Unix domain socket"
+        );
+        boinc_close_socket(lsock);
+        return ERR_LISTEN;
+    }
+#endif
+    return 0;
+}
+
 // If the client runs at boot time,
 // it may be a while (~10 sec) before the DNS system is working.
 // If this returns an error,
 // it will get called once a second for up to 30 seconds.
 // On the last call, "last_time" is set; print error messages then.
 //
-int GUI_RPC_CONN_SET::init(bool last_time) {
+int GUI_RPC_CONN_SET::init_tcp(bool last_time) {
     sockaddr_in addr;
     int retval;
     bool first = true;
@@ -241,11 +288,11 @@ int GUI_RPC_CONN_SET::init(bool last_time) {
         first = false;
     }
 
-    retval = boinc_socket(lsock);
+    retval = boinc_socket(lsock, AF_INET);
     if (retval) {
         if (last_time) {
             msg_printf(NULL, MSG_INTERNAL_ERROR,
-                "GUI RPC failed to create socket: %d", lsock
+                "Failed to create TCP socket: %s", boincerror(retval)
             );
         }
         return retval;
@@ -263,7 +310,7 @@ int GUI_RPC_CONN_SET::init(bool last_time) {
 #ifdef __APPLE__
     addr.sin_addr.s_addr = htonl(INADDR_ANY);
 #else
-    if (config.allow_remote_gui_rpc || remote_hosts_file_exists) {
+    if (cc_config.allow_remote_gui_rpc || remote_hosts_file_exists) {
         addr.sin_addr.s_addr = htonl(INADDR_ANY);
         if (log_flags.gui_rpc_debug) {
             msg_printf(NULL, MSG_INFO, "[gui_rpc] Remote control allowed");
@@ -419,7 +466,9 @@ void GUI_RPC_CONN_SET::got_select(FDSET_GROUP& fg) {
         // 2) client host is included in "remote_hosts" file or
         // 3) client is on localhost
         //
-        if (config.allow_remote_gui_rpc) {
+        if (gstate.gui_rpc_unix_domain) {
+            host_allowed = true;
+        } else if (cc_config.allow_remote_gui_rpc) {
             host_allowed = true;
         } else if (is_localhost(addr)) {
             host_allowed = true;
@@ -438,7 +487,11 @@ void GUI_RPC_CONN_SET::got_select(FDSET_GROUP& fg) {
             if (strlen(password)) {
                 gr->auth_needed = true;
             }
-            gr->is_local = is_localhost(addr);
+            if (gstate.gui_rpc_unix_domain) {
+                gr->is_local = true;
+            } else {
+                gr->is_local = is_localhost(addr);
+            }
             if (log_flags.gui_rpc_debug) {
                 msg_printf(0, MSG_INFO,
                     "[gui_rpc] got new GUI RPC connection"
