@@ -412,8 +412,6 @@ int HTTP_OP::libcurl_exec(
     char buf[256];
     static int outfile_seqno=0;
 
-    safe_strcpy(m_url, url);
-
     if (g_user_agent_string[0] == 0x00) {
         get_user_agent_string();
     }
@@ -441,9 +439,8 @@ int HTTP_OP::libcurl_exec(
     // the following seems to be a no-op
     // curl_easy_setopt(curlEasy, CURLOPT_ERRORBUFFER, error_msg);
 
-    char esc_url[1024];
-    string_substitute(m_url, esc_url, sizeof(esc_url), " ", "%20");
-    curl_easy_setopt(curlEasy, CURLOPT_URL, esc_url);
+    string_substitute(url, m_url, sizeof(m_url), " ", "%20");
+    curl_easy_setopt(curlEasy, CURLOPT_URL, m_url);
 
     // This option determines whether curl verifies that the server
     // claims to be who you want it to be.
@@ -466,6 +463,7 @@ int HTTP_OP::libcurl_exec(
     // To control lying, see CURLOPT_SSL_VERIFYPEER.
     //
     curl_easy_setopt(curlEasy, CURLOPT_SSL_VERIFYHOST, 2L);
+    //curl_easy_setopt(curlEasy, CURLOPT_SSL_VERIFYHOST, 0);
 
     // the following sets "tough" certificate checking
     // (i.e. whether self-signed is OK)
@@ -474,6 +472,7 @@ int HTTP_OP::libcurl_exec(
     // if non-zero below, you need a valid 3rd party CA (i.e. Verisign, Thawte)
     //
     curl_easy_setopt(curlEasy, CURLOPT_SSL_VERIFYPEER, 1L);
+    //curl_easy_setopt(curlEasy, CURLOPT_SSL_VERIFYPEER, FALSE);
 
     // if the above is nonzero, you need the following:
     //
@@ -550,14 +549,14 @@ int HTTP_OP::libcurl_exec(
     // setup timeouts
     //
     curl_easy_setopt(curlEasy, CURLOPT_TIMEOUT, 0L);
-    curl_easy_setopt(curlEasy, CURLOPT_LOW_SPEED_LIMIT, config.http_transfer_timeout_bps);
-    curl_easy_setopt(curlEasy, CURLOPT_LOW_SPEED_TIME, config.http_transfer_timeout);
+    curl_easy_setopt(curlEasy, CURLOPT_LOW_SPEED_LIMIT, cc_config.http_transfer_timeout_bps);
+    curl_easy_setopt(curlEasy, CURLOPT_LOW_SPEED_TIME, cc_config.http_transfer_timeout);
     curl_easy_setopt(curlEasy, CURLOPT_CONNECTTIMEOUT, 120L);
 
     // force curl to use HTTP/1.0 if config specifies it
     // (curl uses 1.1 by default)
     //
-    if (config.http_1_0 || (config.force_auth == "ntlm")) {
+    if (cc_config.http_1_0 || (cc_config.force_auth == "ntlm")) {
         curl_easy_setopt(curlEasy, CURLOPT_HTTP_VERSION, CURL_HTTP_VERSION_1_0);
     }
     curl_easy_setopt(curlEasy, CURLOPT_MAXREDIRS, 50L);
@@ -573,9 +572,9 @@ int HTTP_OP::libcurl_exec(
     // Per: http://curl.haxx.se/dev/readme-encoding.html
     // NULL disables, empty string accepts all.
     if (out) {
-        if (ends_with(out, ".gzt")) {
+        if (ends_with(out, ".gzt") || ends_with(out, ".gz") || ends_with(out, ".tgz")) {
             curl_easy_setopt(curlEasy, CURLOPT_ENCODING, NULL);
-        } else if (!ends_with(out, ".gz")) {
+        } else {
             curl_easy_setopt(curlEasy, CURLOPT_ENCODING, "");
         }
     } else {
@@ -591,10 +590,10 @@ int HTTP_OP::libcurl_exec(
     //
     pcurlList = curl_slist_append(pcurlList, g_content_type);
 
-	if (strlen(gstate.language)) {
-		sprintf(buf, "ACCEPT_LANGUAGE: %s", gstate.language);
-		pcurlList = curl_slist_append(pcurlList, buf);
-	}
+    if (strlen(gstate.language)) {
+        sprintf(buf, "Accept-Language: %s", gstate.language);
+        pcurlList = curl_slist_append(pcurlList, buf);
+    }
 
     // set the file offset for resumable downloads
     //
@@ -830,13 +829,13 @@ void HTTP_OP::setup_proxy_session(bool no_proxy) {
         curl_easy_setopt(curlEasy, CURLOPT_PROXY, (char*) pi.http_server_name);
 
         if (pi.use_http_auth) {
-            if (config.force_auth == "basic") {
+            if (cc_config.force_auth == "basic") {
                 curl_easy_setopt(curlEasy, CURLOPT_PROXYAUTH, CURLAUTH_BASIC);
-            } else if (config.force_auth == "digest") {
+            } else if (cc_config.force_auth == "digest") {
                 curl_easy_setopt(curlEasy, CURLOPT_PROXYAUTH, CURLAUTH_DIGEST);
-            } else if (config.force_auth == "gss-negotiate") {
+            } else if (cc_config.force_auth == "gss-negotiate") {
                 curl_easy_setopt(curlEasy, CURLOPT_PROXYAUTH, CURLAUTH_GSSNEGOTIATE);
-            } else if (config.force_auth == "ntlm") {
+            } else if (cc_config.force_auth == "ntlm") {
                 curl_easy_setopt(curlEasy, CURLOPT_PROXYAUTH, CURLAUTH_NTLM);
             } else {
                 curl_easy_setopt(curlEasy, CURLOPT_PROXYAUTH, CURLAUTH_ANY);
@@ -1001,16 +1000,16 @@ void HTTP_OP::handle_messages(CURLMsg *pcurlMsg) {
 
     if (CurlResult == CURLE_OK) {
         switch ((response/100)*100) {
-        case HTTP_STATUS_OK:
+        case HTTP_STATUS_OK:                        // 200
             http_op_retval = 0;
             break;
-        case HTTP_STATUS_CONTINUE:
+        case HTTP_STATUS_CONTINUE:                  // 100
             return;
-        case HTTP_STATUS_INTERNAL_SERVER_ERROR:
+        case HTTP_STATUS_INTERNAL_SERVER_ERROR:     // 500
             http_op_retval = ERR_HTTP_TRANSIENT;
             safe_strcpy(error_msg, boincerror(response));
             break;
-        default:
+        default:                                    // 400
             http_op_retval = ERR_HTTP_PERMANENT;
             safe_strcpy(error_msg, boincerror(response));
             break;
