@@ -54,6 +54,11 @@ void RESULT::clear() {
     got_server_ack = false;
     final_cpu_time = 0;
     final_elapsed_time = 0;
+    final_peak_working_set_size = 0;
+    final_peak_swap_size = 0;
+    final_peak_disk_usage = 0;
+    final_bytes_sent = 0;
+    final_bytes_received = 0;
 #ifdef SIM
     peak_flop_count = 0;
 #endif
@@ -145,6 +150,11 @@ int RESULT::parse_state(XML_PARSER& xp) {
         }
         if (xp.parse_double("final_cpu_time", final_cpu_time)) continue;
         if (xp.parse_double("final_elapsed_time", final_elapsed_time)) continue;
+        if (xp.parse_double("final_peak_working_set_size", final_peak_working_set_size)) continue;
+        if (xp.parse_double("final_peak_swap_size", final_peak_swap_size)) continue;
+        if (xp.parse_double("final_peak_disk_usage", final_peak_disk_usage)) continue;
+        if (xp.parse_double("final_bytes_sent", final_bytes_sent)) continue;
+        if (xp.parse_double("final_bytes_received", final_bytes_received)) continue;
         if (xp.parse_int("exit_status", exit_status)) continue;
         if (xp.parse_bool("got_server_ack", got_server_ack)) continue;
         if (xp.parse_bool("ready_to_report", ready_to_report)) continue;
@@ -208,6 +218,36 @@ int RESULT::write(MIOFILE& out, bool to_server) {
     if (intops_cumulative) {
         out.printf("    <intops_cumulative>%f</intops_cumulative>\n", intops_cumulative);
     }
+    if (final_peak_working_set_size) {
+        out.printf(
+            "    <final_peak_working_set_size>%.0f</final_peak_working_set_size>\n",
+            final_peak_working_set_size
+        );
+    }
+    if (final_peak_swap_size) {
+        out.printf(
+            "    <final_peak_swap_size>%.0f</final_peak_swap_size>\n",
+            final_peak_swap_size
+        );
+    }
+    if (final_peak_disk_usage) {
+        out.printf(
+            "    <final_peak_disk_usage>%.0f</final_peak_disk_usage>\n",
+            final_peak_disk_usage
+        );
+    }
+    if (final_bytes_sent) {
+        out.printf(
+            "    <final_bytes_sent>%.0f</final_bytes_sent>\n",
+            final_bytes_sent
+        );
+    }
+    if (final_bytes_received) {
+        out.printf(
+            "    <final_bytes_received>%.0f</final_bytes_received>\n",
+            final_bytes_received
+        );
+    }
     if (to_server) {
         out.printf(
             "    <app_version_num>%d</app_version_num>\n",
@@ -328,16 +368,16 @@ int RESULT::write_gui(MIOFILE& out) {
         if (avp->gpu_usage.rsc_type) {
             if (avp->gpu_usage.usage == 1) {
                 sprintf(resources,
-                    "%.3g CPUs + 1 %s GPU",
+                    "%.3g CPUs + 1 %s",
                     avp->avg_ncpus,
-                    rsc_name(avp->gpu_usage.rsc_type)
+                    rsc_name_long(avp->gpu_usage.rsc_type)
                 );
             } else {
                 sprintf(resources,
-                    "%.3g CPUs + %.3g %s GPUs",
+                    "%.3g CPUs + %.3g %ss",
                     avp->avg_ncpus,
                     avp->gpu_usage.usage,
-                    rsc_name(avp->gpu_usage.rsc_type)
+                    rsc_name_long(avp->gpu_usage.rsc_type)
                 );
             }
         } else if (avp->missing_coproc) {
