@@ -180,6 +180,7 @@ void RR_SIM::init_pending_lists() {
     for (unsigned int i=0; i<gstate.results.size(); i++) {
         RESULT* rp = gstate.results[i];
         rp->rr_sim_misses_deadline = false;
+        rp->already_selected = false;
         if (!rp->nearly_runnable()) continue;
         if (rp->some_download_stalled()) continue;
         if (rp->project->non_cpu_intensive) continue;
@@ -268,13 +269,14 @@ void RR_SIM::pick_jobs_to_run(double reltime) {
                 //
                 activate(rp);
                 adjust_rec_sched(rp);
-                if (log_flags.rrsim_detail) {
+                if (log_flags.rrsim_detail && !rp->already_selected) {
                     char buf[256];
                     rsc_string(rp, buf);
                     msg_printf(rp->project, MSG_INFO,
-                        "[rr_sim_detail] %.2f: starting %s (%s)",
-                        reltime, rp->name, buf
+                        "[rr_sim_detail] %.2f: starting %s (%s) (%.2fG/%.2fG)",
+                        reltime, rp->name, buf, rp->rrsim_flops_left/1e9, rp->rrsim_flops/1e9
                     );
+                    rp->already_selected = true;
                 }
 
                 // check whether resource is saturated
@@ -412,6 +414,13 @@ void RR_SIM::simulate() {
         // see if we finish a time slice before first job ends
         //
         double delta_t = rpbest->rrsim_finish_delay;
+        if (log_flags.rrsim_detail) {
+            msg_printf(NULL, MSG_INFO,
+                "[rrsim_detail] rpbest: %s (finish delay %.2f)",
+                rpbest->name,
+                delta_t
+            );
+        }
         if (delta_t > 3600) {
             rpbest = 0;
 
@@ -422,14 +431,22 @@ void RR_SIM::simulate() {
             } else {
                 delta_t = 3600;
             }
+            if (log_flags.rrsim_detail) {
+                msg_printf(NULL, MSG_INFO,
+                    "[rrsim_detail] time-slice step of %.2f sec", delta_t
+                );
+            }
         } else {
             rpbest->rrsim_done = true;
             pbest = rpbest->project;
             if (log_flags.rr_simulation) {
+                char buf[256];
+                rsc_string(rpbest, buf);
                 msg_printf(pbest, MSG_INFO,
-                    "[rr_sim] %.2f: %s finishes (%.2fG/%.2fG)",
-                    sim_now - gstate.now,
+                    "[rr_sim] %.2f: %s finishes (%s) (%.2fG/%.2fG)",
+                    sim_now + delta_t - gstate.now,
                     rpbest->name,
+                    buf,
                     rpbest->estimated_flops_remaining()/1e9, rpbest->rrsim_flops/1e9
                 );
             }
@@ -472,30 +489,9 @@ void RR_SIM::simulate() {
             }
         }
 
-#if 1
         for (int i=0; i<coprocs.n_rsc; i++) {
             rsc_work_fetch[i].update_stats(sim_now, delta_t, buf_end);
         }
-#else
-        // update saturated time
-        //
-        double end_time = sim_now + delta_t;
-        double x = end_time - gstate.now;
-        for (int i=0; i<coprocs.n_rsc; i++) {
-            rsc_work_fetch[i].update_saturated_time(x);
-        }
-
-        // increment resource shortfalls
-        //
-        if (sim_now < buf_end) {
-            if (end_time > buf_end) end_time = buf_end;
-            double d_time = end_time - sim_now;
-
-            for (int i=0; i<coprocs.n_rsc; i++) {
-                rsc_work_fetch[i].accumulate_shortfall(d_time);
-            }
-        }
-#endif
 
         // update project REC
         //
