@@ -15,7 +15,7 @@
 // You should have received a copy of the GNU Lesser General Public License
 // along with BOINC.  If not, see <http://www.gnu.org/licenses/>.
 
-extern void kill_via_switcher(int pid);
+extern int kill_via_switcher(int pid);
 extern int get_project_gid();
 extern int set_to_project_group(const char* path);
 extern int switcher_exec(const char* util_filename, const char* cmdline);
@@ -23,7 +23,7 @@ extern int client_clean_out_dir(const char*, const char* reason);
 extern int delete_project_owned_file(const char* path, bool retry);
 extern int remove_project_owned_dir(const char* name);
 extern int remove_project_owned_file_or_dir(const char* path);
-extern int check_security(int use_sandbox, int isManager);
+extern int check_security(int use_sandbox, int isManager, char* path_to_error, int len);
 
 #define BOINC_PROJECT_GROUP_NAME "boinc_project"
 
