@@ -16,6 +16,7 @@
 // along with BOINC.  If not, see <http://www.gnu.org/licenses/>.
 
 #include "boinc_win.h"
+
 #include "diagnostics.h"
 #include "error_numbers.h"
 #include "filesys.h"
@@ -43,6 +44,46 @@ static HWND g_hWndWindowsMonitorSystemPower = NULL;
 static HANDLE g_hWindowsMonitorSystemProxyThread = NULL;
 
 
+// return true if running under remote desktop
+// (in which case CUDA and Stream apps don't work)
+//
+bool is_remote_desktop() {
+    LPTSTR pBuf = NULL;
+    DWORD dwLength;
+    USHORT usProtocol=0, usConnectionState=0;
+
+    if (WTSQuerySessionInformation(
+        WTS_CURRENT_SERVER_HANDLE,
+        WTS_CURRENT_SESSION,
+        WTSClientProtocolType,
+        &pBuf,
+        &dwLength
+    )) {
+        usProtocol = *(USHORT*)pBuf;
+        WTSFreeMemory(pBuf);
+    }
+
+    if (WTSQuerySessionInformation(
+        WTS_CURRENT_SERVER_HANDLE,
+        WTS_CURRENT_SESSION,
+        WTSConnectState,
+        &pBuf,
+        &dwLength
+    )) {
+        usConnectionState = *(USHORT*)pBuf;
+        WTSFreeMemory(pBuf);
+    }
+
+    // RDP Session implies Remote Desktop
+    if (usProtocol == 2) return true;
+
+    // Fast User Switching keeps the protocol set to the console but changes
+    // the connected state to disconnected.
+    if ((usProtocol == 0) && (usConnectionState == 4)) return true;
+
+    return false;
+}
+
 // The following 3 functions are called in a separate thread,
 // so we can't do anything directly.
 // Set flags telling the main thread what to do.
@@ -188,7 +229,7 @@ static DWORD WINAPI WindowsMonitorSystemPowerThread( LPVOID  ) {
 
     // Initialize diagnostics framework for this thread
     //
-    diagnostics_thread_init(BOINC_DIAG_DEFAULTS);
+    diagnostics_thread_init();
 
     wc.style         = CS_GLOBALCLASS;
     wc.lpfnWndProc   = (WNDPROC)WindowsMonitorSystemPowerWndProc;
@@ -237,26 +278,6 @@ static void windows_detect_autoproxy_settings() {
         post_sysmon_msg("[proxy] automatic proxy check in progress");
     }
 
-    HMODULE hModWinHttp = LoadLibrary("winhttp.dll");
-    if (!hModWinHttp) {
-        return;
-    }
-    pfnWinHttpOpen pWinHttpOpen =
-        (pfnWinHttpOpen)GetProcAddress(hModWinHttp, "WinHttpOpen");
-    if (!pWinHttpOpen) {
-        return;
-    }
-    pfnWinHttpCloseHandle pWinHttpCloseHandle =
-        (pfnWinHttpCloseHandle)(GetProcAddress(hModWinHttp, "WinHttpCloseHandle"));
-    if (!pWinHttpCloseHandle) {
-        return;
-    }
-    pfnWinHttpGetProxyForUrl pWinHttpGetProxyForUrl =
-        (pfnWinHttpGetProxyForUrl)(GetProcAddress(hModWinHttp, "WinHttpGetProxyForUrl"));
-    if (!pWinHttpGetProxyForUrl) {
-        return;
-    }
-
     HINTERNET                 hWinHttp = NULL;
     WINHTTP_AUTOPROXY_OPTIONS autoproxy_options;
     WINHTTP_PROXY_INFO        proxy_info;
@@ -274,9 +295,9 @@ static void windows_detect_autoproxy_settings() {
         WINHTTP_AUTO_DETECT_TYPE_DHCP | WINHTTP_AUTO_DETECT_TYPE_DNS_A;
     autoproxy_options.fAutoLogonIfChallenged = TRUE;
 
-    network_test_url = A2W(config.network_test_url).c_str();
+    network_test_url = A2W(cc_config.network_test_url).c_str();
 
-    hWinHttp = pWinHttpOpen(
+    hWinHttp = WinHttpOpen(
         L"BOINC client",
         WINHTTP_ACCESS_TYPE_DEFAULT_PROXY,
         WINHTTP_NO_PROXY_NAME,
@@ -287,7 +308,7 @@ static void windows_detect_autoproxy_settings() {
     char msg[1024], buf[1024];
     strcpy(msg, "[proxy] ");
 
-    if (pWinHttpGetProxyForUrl(hWinHttp, network_test_url.c_str(), &autoproxy_options, &proxy_info)) {
+    if (WinHttpGetProxyForUrl(hWinHttp, network_test_url.c_str(), &autoproxy_options, &proxy_info)) {
 
         // Apparently there are some conditions where WinHttpGetProxyForUrl can return
         //   success but where proxy_info.lpszProxy is null.  Maybe related to UPNP?
@@ -355,8 +376,7 @@ static void windows_detect_autoproxy_settings() {
             strcat(msg, "no automatic proxy detected");
         }
     }
-    if (hWinHttp) pWinHttpCloseHandle(hWinHttp);
-    FreeLibrary(hModWinHttp);
+    if (hWinHttp) WinHttpCloseHandle(hWinHttp);
     if (log_flags.proxy_debug) {
         post_sysmon_msg(msg);
     }
@@ -366,7 +386,7 @@ static DWORD WINAPI WindowsMonitorSystemProxyThread( LPVOID  ) {
 
     // Initialize diagnostics framework for this thread
     //
-    diagnostics_thread_init(BOINC_DIAG_DEFAULTS);
+    diagnostics_thread_init();
 
     // notify the main client thread that detecting proxies is
     // supported.
