@@ -162,7 +162,7 @@ void CAccountInfoPage::CreateControls()
     m_pAccountInformationStaticCtrl->Create( itemWizardPage56, wxID_STATIC, wxEmptyString, wxDefaultPosition, wxDefaultSize, 0 );
     itemBoxSizer57->Add(m_pAccountInformationStaticCtrl, 0, wxALIGN_LEFT|wxALL, 5);
 
-    wxFlexGridSizer* itemFlexGridSizer64 = new wxFlexGridSizer(4, 2, 0, 0);
+    wxFlexGridSizer* itemFlexGridSizer64 = new wxFlexGridSizer(2, 0, 0);
     itemFlexGridSizer64->AddGrowableCol(1);
     itemBoxSizer57->Add(itemFlexGridSizer64, 0, wxEXPAND|wxALL, 0);
 
@@ -529,7 +529,7 @@ void CAccountInfoPage::OnPageChanged( wxWizardExEvent& event ) {
             _("If you have not yet registered with this account manager,\nplease do so before proceeding.  Click on the link below\nto register or to retrieve a forgotten password." )
         );
         m_pAccountForgotPasswordCtrl->SetLabel(
-            _("Account manager website")
+            _("Account manager web site")
         );
         m_pAccountForgotPasswordCtrl->SetURL(
             wxString(pWA->m_AccountManagerInfoPage->GetProjectURL())
