@@ -71,6 +71,7 @@ public:
 
     void OnOptions( wxCommandEvent& event );
 	void OnPreferences( wxCommandEvent& event );
+	void OnDiagnosticLogFlags( wxCommandEvent& event );
     void OnSelectComputer( wxCommandEvent& event );
     void OnClientShutdown( wxCommandEvent& event );
     void OnRunBenchmarks( wxCommandEvent& event );
@@ -100,10 +101,13 @@ public:
     bool RestoreState();
     bool SaveState();
 
+#ifdef __WXMAC__
+    void                OnKeyPressed(wxKeyEvent &event);
+#endif
+
     wxTimer*        m_pRefreshStateTimer;
     wxTimer*        m_pFrameRenderTimer;
 
-
 protected:
     virtual int     _GetCurrentViewPage();
 
