@@ -234,7 +234,7 @@ void CTermsOfUsePage::OnPageChanged( wxWizardExEvent& event ) {
 
 
     m_pDisagreeCtrl->SetLabel(
-        _("I do not agree with the terms of use.")
+        _("I do not agree to the terms of use.")
     );
     m_pDisagreeCtrl->SetValue(true);
 
