@@ -34,7 +34,6 @@
 #include "MainDocument.h"
 #include "BOINCBaseWizard.h"
 #include "BOINCBaseFrame.h"
-#include "ProjectListCtrl.h"
 #include "WizardAttach.h"
 #include "WelcomePage.h"
 #include "ProjectInfoPage.h"
@@ -402,6 +401,7 @@ bool CWizardAttach::SyncToAccountManager() {
     pDoc->rpc.acct_mgr_info(ami);
 
     if (ami.acct_mgr_url.size()) {
+        m_strProjectName = wxString(ami.acct_mgr_name.c_str(), wxConvUTF8);
         m_AccountManagerInfoPage->SetProjectURL( 
             wxString(ami.acct_mgr_url.c_str(), wxConvUTF8)
         );
@@ -624,12 +624,14 @@ wxWizardPageEx* CWizardAttach::_PushPageTransition( wxWizardPageEx* pCurrentPage
     }
     return NULL;
 }
-  
+
 void CWizardAttach::_ProcessCancelEvent( wxWizardExEvent& event ) {
 
     bool bCancelWithoutNextPage = false;
     wxWizardPageEx* page = GetCurrentPage();
 
+    m_bCancelInProgress = true;
+
     int iRetVal = wxGetApp().SafeMessageBox(
         _("Do you really want to cancel?"), 
         _("Question"),
@@ -641,28 +643,6 @@ void CWizardAttach::_ProcessCancelEvent( wxWizardExEvent& event ) {
     GetNextButton()->Enable();
     GetBackButton()->Enable();
 
-    // Page specific rules - Disable the validator(s)
-    if (wxYES == iRetVal) {
-        if ((page == m_ProjectInfoPage) || (page == m_AccountManagerInfoPage)) {
-            m_ProjectInfoPage->m_pProjectURLCtrl->SetValidator(wxDefaultValidator);
-        } else if (page == m_AccountInfoPage) {
-            m_AccountInfoPage->m_pAccountEmailAddressCtrl->SetValidator(wxDefaultValidator);
-            m_AccountInfoPage->m_pAccountPasswordCtrl->SetValidator(wxDefaultValidator);
-            if (IsAttachToProjectWizard) {
-                m_AccountInfoPage->m_pAccountConfirmPasswordCtrl->SetValidator(wxDefaultValidator);
-            }
-        } else if (page == m_ErrProxyPage) {
-            m_ErrProxyPage->m_pProxyHTTPServerCtrl->SetValidator(wxDefaultValidator);
-            m_ErrProxyPage->m_pProxyHTTPPortCtrl->SetValidator(wxDefaultValidator);
-            m_ErrProxyPage->m_pProxyHTTPUsernameCtrl->SetValidator(wxDefaultValidator);
-            m_ErrProxyPage->m_pProxyHTTPPasswordCtrl->SetValidator(wxDefaultValidator);
-            m_ErrProxyPage->m_pProxySOCKSServerCtrl->SetValidator(wxDefaultValidator);
-            m_ErrProxyPage->m_pProxySOCKSPortCtrl->SetValidator(wxDefaultValidator);
-            m_ErrProxyPage->m_pProxySOCKSUsernameCtrl->SetValidator(wxDefaultValidator);
-            m_ErrProxyPage->m_pProxySOCKSPasswordCtrl->SetValidator(wxDefaultValidator);
-        }
-    }
-
     // Generic rules
     bCancelWithoutNextPage |= (page == m_ErrNotDetectedPage);
     bCancelWithoutNextPage |= (page == m_ErrUnavailablePage);
@@ -673,8 +653,12 @@ void CWizardAttach::_ProcessCancelEvent( wxWizardExEvent& event ) {
     } else {
         bCancelWithoutNextPage |= (page == m_WelcomePage);
     }
+
     if (wxYES != iRetVal) {
         event.Veto();
+        m_bCancelInProgress = false;
+    } else {
+        m_bCancelInProgress = true;
     }
 }
 
