@@ -25,7 +25,6 @@
 #pragma interface "sg_BoincSimpleFrame.cpp"
 #endif
 
-class CTransparentButton;
 class CSimpleTaskPanel;
 class CSimpleProjectPanel;
 class CSimpleTaskPanel;
@@ -72,17 +71,12 @@ protected:
     void OnPaint(wxPaintEvent& event);
     void OnEraseBackground(wxEraseEvent& event);
 #ifdef __WXMAC__
-//    void SetupMacAccessibilitySupport();
-//    void RemoveMacAccessibilitySupport();
-    
-//    EventHandlerRef m_pSGAccessibilityEventHandlerRef;
-
     int         m_iRedRingRadius;
 #endif
     wxBitmap    m_bmpBg;
-    CTransparentButton *m_NoticesButton;
-    CTransparentButton *m_SuspendResumeButton;
-    CTransparentButton *m_HelpButton;
+    wxButton    *m_NoticesButton;
+    wxButton    *m_SuspendResumeButton;
+    wxButton    *m_HelpButton;
     wxString    m_sSuspendString;
     wxString    m_sResumeString;
     int         m_oldWorkCount;
@@ -104,7 +98,7 @@ class CSimpleFrame : public CBOINCBaseFrame
 
 public:
     CSimpleFrame();
-    CSimpleFrame(wxString title, wxIcon* icon, wxIcon* icon32, wxPoint position, wxSize size);
+    CSimpleFrame(wxString title, wxIconBundle* icons, wxPoint position, wxSize size);
 
    ~CSimpleFrame();
 
@@ -114,6 +108,7 @@ public:
     void OnSelectSkin( wxCommandEvent& event );
     void OnPreferences( wxCommandEvent& event );
     void OnOptions( wxCommandEvent& event );
+    void OnDiagnosticLogFlags( wxCommandEvent& event );
     void OnOldSG( wxCommandEvent& event );
     void OnHelp( wxHelpEvent& event );
     void OnHelpBOINC( wxCommandEvent& event );
@@ -130,15 +125,17 @@ public:
 	void SetMsgsDlgOpen(CDlgMessages* newDlgPtr) { dlgMsgsPtr = newDlgPtr; }
     bool isMessagesDlgOpen() { return (dlgMsgsPtr != NULL); }
 
+    bool SaveWindowPosition();
     bool SaveState();
     bool RestoreState();
+    void OnMove(wxMoveEvent& event);
 
 protected:
     virtual int     _GetCurrentViewPage();
 
 	wxMenuBar*          m_pMenubar;
     wxMenu*             m_pSubmenuSkins;
-    wxAcceleratorEntry  m_Shortcuts[2];
+    wxAcceleratorEntry  m_Shortcuts[3];
     wxAcceleratorTable* m_pAccelTable;
 
 	CSimpleGUIPanel* m_pBackgroundPanel;
