@@ -112,18 +112,13 @@ const char *  RunningOnBatteryMsg = "Computing and screensaver disabled while ru
 // multiple times (once for each display), so we need to guard 
 // against any problems that may cause.
 void initBOINCSaver() {
-#ifdef _DEBUG
-    char buf1[256], buf2[256];
-    safe_strcpy(buf1, getenv("HOME"));
-    safe_strcat(buf1, "/Documents/ss_stdout");
-    safe_strcpy(buf2, getenv("HOME"));
-    safe_strcat(buf2, "/Documents/ss_stderr");
-
-    diagnostics_init(BOINC_DIAG_REDIRECTSTDOUTOVERWRITE
-        | BOINC_DIAG_REDIRECTSTDERROVERWRITE
-        | BOINC_DIAG_TRACETOSTDOUT, buf1, buf2
+    diagnostics_init(
+        BOINC_DIAG_PERUSERLOGFILES |
+        BOINC_DIAG_REDIRECTSTDOUT |
+        BOINC_DIAG_REDIRECTSTDERR |
+        BOINC_DIAG_TRACETOSTDOUT,
+        "stdoutscr", "stderrscr"
         );
-#endif
 
     if (gspScreensaver == NULL) {
         gspScreensaver = new CScreensaver();
@@ -443,7 +438,7 @@ int CScreensaver::getSSMessage(char **theMessage, int* coveredFreq) {
     int newFrequency = TEXTLOGOFREQUENCY;
     *coveredFreq = 0;
     pid_t myPid;
-    CC_STATE state;
+    CC_STATE ccstate;
     OSStatus err;
     
     if (ScreenIsBlanked) {
@@ -472,11 +467,11 @@ int CScreensaver::getSSMessage(char **theMessage, int* coveredFreq) {
             if (!rpc->init(NULL)) {     // Initialize communications with Core Client
                 m_bConnected = true;
                 if (IsDualGPUMacbook) {
-                    state.clear();
-                    state.global_prefs.clear_bools();
-                    int result = rpc->get_state(state);
+                    ccstate.clear();
+                    ccstate.global_prefs.clear_bools();
+                    int result = rpc->get_state(ccstate);
                     if (!result) {
-                        OKToRunOnBatteries = state.global_prefs.run_on_batteries;
+                        OKToRunOnBatteries = ccstate.global_prefs.run_on_batteries;
                     } else {
                         OKToRunOnBatteries = false;
                     }
