@@ -201,6 +201,9 @@ struct USER {
         // is being verified.
     bool has_profile;
     char cross_project_id[256];
+        // the "internal" cross-project ID;
+        // the "external CPID" that  gets exported to stats sites
+        // is MD5(cpid, email)
     char passwd_hash[256];
     bool email_validated;           // deprecated
     int donated;
@@ -347,6 +350,8 @@ struct HOST {
     //
     char p_features[1024];
     char virtualbox_version[256];
+    char client_brand[256];
+        // as specific in client_brand.txt config file on client
     bool p_vm_extensions_disabled;
     int num_opencl_cpu_platforms;
     OPENCL_CPU_PROP opencl_cpu_prop[MAX_OPENCL_CPU_PLATFORMS];
