@@ -1,7 +1,7 @@
 <?php
 // This file is part of BOINC.
 // http://boinc.berkeley.edu
-// Copyright (C) 2008 University of California
+// Copyright (C) 2014 University of California
 //
 // BOINC is free software; you can redistribute it and/or modify it
 // under the terms of the GNU Lesser General Public License
@@ -33,24 +33,33 @@ admin_page_head($title);
 echo "<ul>\n";
 
 if (!file_exists(".htaccess")) {
-    echo "<li><span style=\"color: #ff0000\">The Project Management directory is not
-        protected from public access by a .htaccess file.</span></li>\n";
+    echo "<li><span style=\"color: #ff0000\">
+        The Project Management directory is not
+        protected from public access by a .htaccess file.
+        </span></li>
+    ";
 }
 
 if (!defined("SYS_ADMIN_EMAIL")) {
-    echo "<li><span style=\"color: #ff0000\">The defined constant SYS_ADMIN_EMAIL
+    echo "<li><span style=\"color: #ff0000\">
+        The defined constant SYS_ADMIN_EMAIL
         has not been set. Please edit <tt>project/project.inc</tt> and set this
         to an address which can be used to contact the project administrators.
-        </span></li>\n";
+        </span></li>
+    ";
 }
 
 if (parse_bool($config, "disable_account_creation")) {
-    echo "<li><span style=\"color: #ff9900\">Account creation is disabled.</span></li>\n";
+    echo "<li><span style=\"color: #ff9900\">
+        Account creation is disabled.</span></li>
+    ";
 }
 
 if (defined("INVITE_CODES")) {
-    echo "<li><span style=\"color: #ff9900\">Account creation is restricted by the use of
-        invitation codes.</span></li>\n";
+    echo "<li><span style=\"color: #ff9900\">
+        Account creation is restricted by the use of
+        invitation codes.</span></li>
+    ";
 }
 
 $uotd_candidates = count_uotd_candidates();
@@ -62,8 +71,10 @@ if ($uotd_candidates >= 0) {
     } else {
         $color = "#ff9900";
     }
-    echo "<li><span style=\"color: ".$color."\">There are ".$uotd_candidates." remaining
-        candidates for User of the Day.</span></li>\n";
+    echo "<li><span style=\"color: ".$color."\">
+        There are ".$uotd_candidates." remaining candidates for User of the Day.
+        </span></li>
+    ";
 }
 
 echo "</ul>\n";
@@ -113,17 +124,17 @@ echo "
     </td> 
     <td><b>User management</b>
     <ul>
+        <li><a href=".URL_BASE."/forum_index.php>Post news item</a></li>
         <li><a href=\"profile_screen_form.php\">Screen user profiles </a></li>
+        <li><a href=\"badge_admin.php\">Badges</a></li>
         <li><a href=\"manage_special_users.php\">User privileges</a></li>
         <li><a href=".URL_BASE."/manage_project.php>User job submission privileges</a></li>
         <li><a href=\"mass_email.php\">Send mass email to a selected set of users</a></li>
-        <li><a href=\"problem_host.php\">Email user with misconfigured host</a></li>
         <li><form action=\"manage_user.php\">
             <input type=\"submit\" value=\"Manage user\">
             ID: <input name=\"userid\">
             </form>
         </li>
-        </li>
     </ul>
     </td>
     </tr>
@@ -134,8 +145,8 @@ echo "
 
 $show_deprecated = get_str("show_deprecated", true);
 $show_only = array("all"); // Add all appids you want to display, or "all"
-$result = mysql_query("select id, name, deprecated from app");
-while ($app = mysql_fetch_object($result)) {
+$apps = BoincApp::enum("");
+foreach ($apps as $app) {
     if (in_array($app->id, $show_only) 
        || ( in_array("all", $show_only)
           && (!$app->deprecated || $show_deprecated)
@@ -172,7 +183,6 @@ while ($app = mysql_fetch_object($result)) {
         echo " </ul> ";
     }
 }
-mysql_free_result($result);
 
 if ($show_deprecated) {
     echo "<a href=\"index.php?show_deprecated=0\">Hide deprecated applications</a>";
@@ -180,19 +190,26 @@ if ($show_deprecated) {
     echo "<a href=\"index.php?show_deprecated=1\">Show deprecated applications</a>";
 }
 
-// Periodic tasks
+echo "<h3>Periodic tasks</h3>
+The following scripts should be run as periodic tasks, not via this web page
+(see <a href=\"http://boinc.berkeley.edu/trac/wiki/ProjectTasks\">http://boinc.berkeley.edu/trac/wiki/ProjectTasks</a>):
+<pre>
+    update_forum_activities.php, update_profile_pages.php, update_uotd.php
+</pre>
 
-echo "<h3>Periodic or special tasks</h3>
+<h3>Repair tasks</h3>
+The following scripts do one-time repair operations.
+Run them manually on the command line as needed
+(i.e. <tt>php scriptname.php</tt>):
+<pre>forum_repair.php, team_repair.php, repair_validator_problem.php</pre>
+
+<h3>Cleanup tasks</h3>
+You can run the following as a periodic task, on the command line,
+or by clicking here:
     <ul>
-    <li> The following scripts should be run as periodic tasks,
-        not via this web page
-        (see <a href=\"http://boinc.berkeley.edu/trac/wiki/ProjectTasks\">http://boinc.berkeley.edu/trac/wiki/ProjectTasks</a>):
-        <pre> update_forum_activities.php, update_profile_pages.php, update_uotd.php</pre>
-    <li> The following scripts can be run manually on the command line
-        as needed (i.e. <tt>php scriptname.php</tt>):
-        <pre>forum_repair.php, team_repair.php, repair_validator_problem.php</pre>
-   </ul>
-    ";
+    <li> <a href=remove_zombie_hosts.php>remove_zombie_hosts.php</a> Remove zombie host records
+    </ul>
+";
 
 admin_page_tail();
 
