@@ -37,12 +37,15 @@ function do_updates() {
     $n = post_str("homogeneous_app_version", true)?1:0;
     $app->update("homogeneous_app_version=$n");
 
-    $n = post_str("cpu_intensive", true)?1:0;
+    $n = post_str("non_cpu_intensive", true)?1:0;
     $app->update("non_cpu_intensive=$n");
 
     $n = post_str("beta", true)?1:0;
     $app->update("beta=$n");
 
+    $n = post_str("fraction_done_exact", true)?1:0;
+    $app->update("fraction_done_exact=$n");
+
     echo "Application $id updated.
         <p>
         You must restart the project for this to take effect.
@@ -50,8 +53,8 @@ function do_updates() {
 }
 
 function add_app() {
-    $name = mysql_real_escape_string(post_str('add_name'));
-    $user_friendly_name = mysql_real_escape_string(post_str('add_user_friendly_name'));
+    $name = BoincDb::escape_string(post_str('add_name'));
+    $user_friendly_name = BoincDb::escape_string(post_str('add_user_friendly_name'));
     if (empty($name) || empty($user_friendly_name) ) {
         error_page(
             "To add a new application please supply both a brief name and a longer 'user-friendly' name.</font></p>"
@@ -82,11 +85,13 @@ function show_form() {
         "Created",
         "weight<br><a href=http://boinc.berkeley.edu/trac/wiki/BackendPrograms#feeder><span class=note>details</span></a>",
         "shmem items",
-        "homogeneous redundancy type<br><a href=http://boinc.berkeley.edu/trac/wiki/HomogeneousRedundancy><span class=note>details</span></a>",
+        "HR type<br><a href=http://boinc.berkeley.edu/trac/wiki/HomogeneousRedundancy><span class=note>details</span></a>",
         "homogeneous app version?<br><a href=http://boinc.berkeley.edu/trac/wiki/HomogeneousAppVersion><span class=note>details</span></a>",
         "deprecated?",
         "Non-CPU-intensive?",
-        "Beta?"
+        "Beta?",
+        "Exact fraction done?",
+        ""
     );
 
     $total_weight = BoincApp::sum("weight");
@@ -96,6 +101,7 @@ function show_form() {
     }
 
     $apps = BoincApp::enum("");
+    $i = 0;
     foreach ($apps as $app) {
         // grey-out deprecated versions
         $f1=$f2='';
@@ -103,7 +109,8 @@ function show_form() {
             $f1 = "<font color='GREY'>";
             $f2 = "</font>";
         }
-        echo "<tr><form action=manage_apps.php method=POST>";
+        echo "<tr class=row$i><form action=manage_apps.php method=POST>";
+        $i = 1-$i;
         echo "<input type=hidden name=id value=$app->id>";
         echo "  <TD align='center'>$f1 $app->id $f2</TD>\n";
 
@@ -150,6 +157,12 @@ function show_form() {
             <input name='beta' type='checkbox' $v></TD>
         ";
 
+        $v = '';
+        if ($app->fraction_done_exact) $v = ' CHECKED ';
+        echo "  <TD align='center'>
+            <input name='fraction_done_exact' type='checkbox' $v></TD>
+        ";
+
         echo "<td><input type=submit name=submit value=Update>";
         echo "</tr></form>";
     }
