@@ -21,7 +21,7 @@ require_once("../inc/forum.inc");
 require_once("../inc/image.inc"); // Avatar scaling
 
 if (post_str("account_key", true) != null) {
-    $user = lookup_user_auth(post_str("account_key"));
+    $user = BoincUser::lookup_auth(post_str("account_key"));
     $rpc = true;
 } else {
     $user = get_logged_in_user();
@@ -59,6 +59,13 @@ if (post_str("action", true)=="reset"){
     exit;
 }
 
+$pmn = post_int("pm_notification");
+if ($pmn != $user->prefs->pm_notification) {
+    $user->prefs->update("pm_notification=$pmn");
+}
+
+if (!DISABLE_FORUMS) {
+
 $avatar_type = post_int("avatar_select");
 $newfile=IMAGE_PATH.$user->id."_avatar.jpg";
 
@@ -108,7 +115,6 @@ $highlight_special = ($_POST["forum_highlight_special"]!="")?1:0;
 $jump_to_unread = ($_POST["forum_jump_to_unread"]!="")?1:0;
 $ignore_sticky_posts = ($_POST["forum_ignore_sticky_posts"]!="")?1:0;
 $no_signature_by_default = ($_POST["signature_by_default"]!="")?0:1;
-$pm_notification = post_int("pm_notification");
 $signature = post_str("signature", true);
 if (strlen($signature)>250) {
     error_page(tra("Your signature was too long, please keep it less than 250 characters."));
@@ -120,8 +126,9 @@ if ($display_wrap_postcount<1) $display_wrap_postcount=1;
 
 $signature = BoincDb::escape_string($signature);
 
-$user->prefs->update("images_as_links=$images_as_links, link_popup=$link_popup, hide_avatars=$hide_avatars, hide_signatures=$hide_signatures, highlight_special=$highlight_special, jump_to_unread=$jump_to_unread, ignore_sticky_posts=$ignore_sticky_posts, no_signature_by_default=$no_signature_by_default, pm_notification=$pm_notification, avatar='$avatar_url', signature='$signature', forum_sorting=$forum_sort, thread_sorting=$thread_sort, display_wrap_postcount=$display_wrap_postcount");
+$user->prefs->update("images_as_links=$images_as_links, link_popup=$link_popup, hide_avatars=$hide_avatars, hide_signatures=$hide_signatures, highlight_special=$highlight_special, jump_to_unread=$jump_to_unread, ignore_sticky_posts=$ignore_sticky_posts, no_signature_by_default=$no_signature_by_default, avatar='$avatar_url', signature='$signature', forum_sorting=$forum_sort, thread_sorting=$thread_sort, display_wrap_postcount=$display_wrap_postcount");
 
+}   // DISABLE_FORUMS
 
 $add_user_to_filter = ($_POST["add_user_to_filter"]!="");
 if ($add_user_to_filter){
