@@ -16,13 +16,10 @@
 // You should have received a copy of the GNU Lesser General Public License
 // along with BOINC.  If not, see <http://www.gnu.org/licenses/>.
 
-require_once("../inc/db.inc");
 require_once("../inc/util.inc");
 
 check_get_args(array());
 
-db_init();
-
 $user = get_logged_in_user(false);
 
 page_head(tra("Change password"));
