@@ -1,7 +1,7 @@
 <?php
 // This file is part of BOINC.
 // http://boinc.berkeley.edu
-// Copyright (C) 2008 University of California
+// Copyright (C) 2014 University of California
 //
 // BOINC is free software; you can redistribute it and/or modify it
 // under the terms of the GNU Lesser General Public License
@@ -26,6 +26,11 @@ require_once('../inc/time.inc');
 check_get_args(array("read", "return", "tnow", "ttok"));
 
 $user = get_logged_in_user(false);
+BoincForumPrefs::lookup($user);
+
+if (DISABLE_FORUMS && !is_admin($user)) {
+    error_page("Forums are disabled");
+}
 
 // Process request to mark all posts as read
 //
