@@ -36,6 +36,10 @@ check_banished($logged_in_user);
 $forumid = get_int("id");
 $forum = BoincForum::lookup_id($forumid);
 
+if (DISABLE_FORUMS && !is_admin($logged_in_user)) {
+    error_page("Forums are disabled");
+}
+
 if (!user_can_create_thread($logged_in_user, $forum)) {
     error_page(tra("Only project admins may create a thread here. However, you may reply to existing threads."));
 }
