@@ -1,7 +1,7 @@
 <?php
 // This file is part of BOINC.
 // http://boinc.berkeley.edu
-// Copyright (C) 2008 University of California
+// Copyright (C) 2014 University of California
 //
 // BOINC is free software; you can redistribute it and/or modify it
 // under the terms of the GNU Lesser General Public License
@@ -19,11 +19,14 @@
 // Post a reply to a thread.
 // Both input (form) and action take place here.
 
+require_once('../inc/util.inc');
 require_once('../inc/forum_email.inc');
 require_once('../inc/forum.inc');
 require_once('../inc/bbcode_html.inc');
 require_once('../inc/akismet.inc');
 
+if (DISABLE_FORUMS) error_page("Forums are disabled");
+
 $logged_in_user = get_logged_in_user(true);
 BoincForumPrefs::lookup($logged_in_user);
 check_banished($logged_in_user);
