@@ -1,7 +1,7 @@
 <?php
 // This file is part of BOINC.
 // http://boinc.berkeley.edu
-// Copyright (C) 2008 University of California
+// Copyright (C) 2014 University of California
 //
 // BOINC is free software; you can redistribute it and/or modify it
 // under the terms of the GNU Lesser General Public License
@@ -21,9 +21,12 @@
 // For this file to work the project must have defined who
 // should receive such reports (in the configuration file)
 
+require_once('../inc/util.inc');
 require_once('../inc/forum.inc');
 require_once('../inc/forum_email.inc');
 
+if (DISABLE_FORUMS) error_page("Forums are disabled");
+
 check_get_args(array("post", "submit", "reason", "tnow", "ttok"));
 
 $postId = get_int('post');
