@@ -1,7 +1,7 @@
 <?php
 // This file is part of BOINC.
 // http://boinc.berkeley.edu
-// Copyright (C) 2008 University of California
+// Copyright (C) 2014 University of California
 //
 // BOINC is free software; you can redistribute it and/or modify it
 // under the terms of the GNU Lesser General Public License
@@ -23,6 +23,8 @@ require_once("../inc/util.inc");
 require_once("../inc/team.inc");
 require_once("../inc/boinc_db.inc");
 
+if (DISABLE_TEAMS) error_page("Teams are disabled");
+
 check_get_args(array("teamid"));
 
 $user = get_logged_in_user();
@@ -104,14 +106,14 @@ if ($navailable_users > 0) {
     end_table();
     echo "<input type=submit value=\"".tra("Change founder")."\">";
 } else {
-    echo '<tr>
-        <td colspan="4">".tra("There are no users to transfer team to.")."</td>
+    echo "<tr>
+        <td colspan='4'>".tra("There are no users to transfer team to.")."</td>
         </tr>
-    ';
+    ";
     end_table();
 }
 echo "</form>";
 page_tail();
 
-$cvs_version_tracker[]="\$Id: team_change_founder_form.php 23010 2011-02-09 22:11:34Z davea $";  //Generated automatically - do not edit
+$cvs_version_tracker[]="\$Id$";  //Generated automatically - do not edit
 ?>
