@@ -1,7 +1,7 @@
 <?php
 // This file is part of BOINC.
 // http://boinc.berkeley.edu
-// Copyright (C) 2008 University of California
+// Copyright (C) 2014 University of California
 //
 // BOINC is free software; you can redistribute it and/or modify it
 // under the terms of the GNU Lesser General Public License
@@ -29,6 +29,8 @@ require_once("../inc/team.inc");
 require_once("../inc/email.inc");
 require_once("../inc/pm.inc");
 
+if (DISABLE_TEAMS) error_page("Teams are disabled");
+
 check_get_args(array());
 
 $user = get_logged_in_user();
@@ -37,7 +39,7 @@ if (!$user->teamid) {
 }
 
 function send_founder_transfer_email($team, $user) {
-    $founder = lookup_user_id($team->userid);
+    $founder = BoincUser::lookup_id($team->userid);
 
     // send founder a private message for good measure
 
