@@ -1,7 +1,7 @@
 <?php
 // This file is part of BOINC.
 // http://boinc.berkeley.edu
-// Copyright (C) 2008 University of California
+// Copyright (C) 2014 University of California
 //
 // BOINC is free software; you can redistribute it and/or modify it
 // under the terms of the GNU Lesser General Public License
@@ -20,6 +20,8 @@ require_once("../inc/boinc_db.inc");
 require_once("../inc/util.inc");
 require_once("../inc/team.inc");
 
+if (DISABLE_TEAMS) error_page("Teams are disabled");
+
 check_get_args(array("format", "team_id", "team_ids", "team_name"));
 
 $format = get_str("format", true);
@@ -38,7 +40,7 @@ if ($team_id) {
     if ($team) {
         show_team_xml($team);
     } else {
-        xml_error(-136);
+        xml_error(ERR_DB_NOT_FOUND);
     }
     exit();
 }
