@@ -50,6 +50,7 @@
 #define BOINC_DIAG_TRACETOSTDOUT            0x00000400L
 #define BOINC_DIAG_HEAPCHECKEVERYALLOC      0x00000800L
 #define BOINC_DIAG_BOINCAPPLICATION         0x00001000L
+#define BOINC_DIAG_PERUSERLOGFILES          0x00002000L
 #define BOINC_DIAG_DEFAULTS \
     BOINC_DIAG_DUMPCALLSTACKENABLED | \
     BOINC_DIAG_HEAPCHECKENABLED | \
@@ -80,7 +81,7 @@ extern int boinc_finish_diag();
 extern int diagnostics_init(
     int flags, const char* stdout_prefix, const char* stderr_prefix
 );
-extern int diagnostics_thread_init( int flags );
+extern int diagnostics_thread_init();
 extern int diagnostics_finish();
 extern int diagnostics_is_initialized();
 extern int diagnostics_is_flag_set(int flags);
@@ -107,12 +108,13 @@ extern int diagnostics_update_thread_list();
 extern int diagnostics_set_thread_exempt_suspend();
 extern int diagnostics_is_thread_exempt_suspend(long thread_id);
 
-// Message Monitoring
+// Message Monitoring (debugger viewport)
 extern int diagnostics_init_message_monitor();
 extern int diagnostics_finish_message_monitor();
 #ifdef _WIN32
 extern UINT WINAPI diagnostics_message_monitor(LPVOID lpParameter);
 #endif
+extern int diagnostics_trace_to_debugger(const char* msg);
 
 // Unhandled exception monitor
 extern int diagnostics_init_unhandled_exception_monitor();
