@@ -57,8 +57,13 @@
 using std::vector;
 
 // see:
-// man 5 proc
-// /usr/src/linux/fs/proc/array.C
+// http://git.kernel.org/cgit/linux/kernel/git/torvalds/linux.git/tree/fs/proc/array.c
+//
+// Interesting note: the command part of /proc/PID/stat is the first
+// 15 characters of the executable filename.
+// If you want the entire filename, or the rest of the cmdline,
+// you need to parse /proc/PID/cmdline,
+// which is the cmdline with NULL separators
 
 struct PROC_STAT {
     int pid;
@@ -157,16 +162,13 @@ int PROC_STAT::parse(char* buf) {
         return 0;
     }
 
-    // I don't see a good choice of ERR_ for this...
-    //
+    //fprintf(stderr, "can't parse /proc/x/stat file: %s\n", buf);
     return 1;
 }
 
 // build table of all processes in system
 //
 int procinfo_setup(PROC_MAP& pm) {
-
-#if HAVE_DIRENT_H
     DIR *dir;
     dirent *piddir;
     FILE* fd;
@@ -174,10 +176,13 @@ int procinfo_setup(PROC_MAP& pm) {
     char pidpath[MAXPATHLEN];
     char buf[1024];
     int pid = getpid();
-    int retval, final_retval = 0;
+    int retval;
 
     dir = opendir("/proc");
-    if (!dir) return 0;
+    if (!dir) {
+        fprintf(stderr, "procinfo_setup(): can't open /proc\n");
+        return 0;
+    }
 
     while (1) {
         piddir = readdir(dir);
@@ -226,7 +231,9 @@ int procinfo_setup(PROC_MAP& pm) {
         fclose(fd);
 
         if (retval) {
-            final_retval = retval;
+            // ps.parse() returns an error if the executable name contains ).
+            // In that case skip this process.
+            //
             continue;
         }
         PROCINFO p;
@@ -246,14 +253,13 @@ int procinfo_setup(PROC_MAP& pm) {
         strlcpy(p.command, ps.comm, sizeof(p.command));
         p.is_boinc_app = (p.id == pid || strcasestr(p.command, "boinc"));
         p.is_low_priority = (ps.priority == 39);
-            // Linux seems to add 20 here,
-            // but this isn't documented anywhere
+            // Internally Linux stores the process priority as nice + 20
+            // as -ve values are error codes. Thus this generally gives
+            // a process priority range of 39..0
         pm.insert(std::pair<int, PROCINFO>(p.id, p));
 #endif
     }
     closedir(dir);
-#endif
     find_children(pm);
-    return final_retval;
-
+    return 0;
 }
