@@ -15,22 +15,29 @@
 // You should have received a copy of the GNU Lesser General Public License
 // along with BOINC.  If not, see <http://www.gnu.org/licenses/>.
 
-// C++ interfaces to remote job submissions and file management RPCs
+// C++ interfaces to remote job submission and file management RPCs
+// See http://boinc.berkeley.edu/trac/wiki/RemoteJobs#Cinterface
+
+#ifndef REMOTE_SUBMIT_H
+#define REMOTE_SUBMIT_H
 
 #include <stdio.h>
 #include <string>
 #include <vector>
 #include <map>
 
+#include "parse.h"
+
 using std::string;
 using std::vector;
 using std::map;
 
 struct INFILE {
+    char physical_name[256];    // BOINC physical name
     char src_path[256];         // path on submit machine
-    char dst_filename[256];
+    char logical_name[256];
         // filename on execution machine.
-        // must agree with the app's input template
+        // not used; could be used to check consistency w/ input template
 };
 
 struct JOB {
@@ -44,24 +51,16 @@ struct LOCAL_FILE {
     double nbytes;
 };
 
-struct SUBMIT_REQ {
-    char batch_name[256];
-    char app_name[256];
-    vector<JOB> jobs;
-    map<string, LOCAL_FILE> local_files;
-        // maps local path to info about file
-    int batch_id;
-};
-
-struct QUERY_BATCH_JOB {
+struct JOB_STATUS {
     string job_name;
     string status;
-    QUERY_BATCH_JOB(){}
+    JOB_STATUS(){}
 };
 
-struct QUERY_BATCH_REPLY {
+struct QUERY_BATCH_SET_REPLY {
+    double server_time;         // server time at start of query
     vector<int> batch_sizes;    // how many jobs in each of the queried batches
-    vector<QUERY_BATCH_JOB> jobs;   // the jobs, sequentially
+    vector<JOB_STATUS> jobs;    // the jobs, sequentially
 };
 
 struct OUTFILE {
@@ -106,7 +105,6 @@ struct COMPLETED_JOB_DESC {
 extern int query_files(
     const char* project_url,
     const char* authenticator,
-    vector<string> &paths,
     vector<string> &md5s,
     int batch_id,
     vector<int> &absent_files,
@@ -127,6 +125,7 @@ extern int create_batch(
     const char* authenticator,
     const char* batch_name,
     const char* app_name,
+    double expire_time,
     int &batch_id,
     string& error_msg
 );
@@ -134,15 +133,81 @@ extern int create_batch(
 extern int submit_jobs(
     const char* project_url,
     const char* authenticator,
-    SUBMIT_REQ &req,
+    char app_name[256],
+    int batch_id,
+    vector<JOB> jobs,
     string& error_msg
 );
 
+extern int estimate_batch(
+    const char* project_url,
+    const char* authenticator,
+    char app_name[256],
+    vector<JOB> jobs,
+    double& est_makespan,
+    string& error_msg
+);
+
+// Return the short status of the jobs in a given set of batches
+// Used by the Condor interface
+//
+extern int query_batch_set(
+    const char* project_url,
+    const char* authenticator,
+    double min_mod_time,
+    vector<string> &batch_names,
+    QUERY_BATCH_SET_REPLY& reply,
+    string& error_msg
+);
+
+struct BATCH_STATUS {
+    int id;
+    char name[256];             // name of batch
+    char app_name[256];
+    int state;                  // see lib/common_defs.h
+    int njobs;                  // how many jobs in batch
+    int nerror_jobs;            // how many jobs errored out
+    double fraction_done;       // how much of batch is done (0..1)
+    double create_time;         // when batch was created
+    double expire_time;         // when it will expire
+    double est_completion_time;     // estimated completion time
+    double completion_time;     // if completed, actual completion time
+    double credit_estimate;     // original estimate for credit
+    double credit_canonical;    // if completed, granted credit
+
+    int parse(XML_PARSER&);
+    void print();
+};
+
+// Return a list of this user's batches
+//
 extern int query_batches(
     const char* project_url,
     const char* authenticator,
-    vector<string> &batch_names,
-    QUERY_BATCH_REPLY& reply,
+    vector<BATCH_STATUS>& batches,
+    string& error_msg
+);
+
+struct JOB_STATE {
+    int id;
+    char name[256];
+    int canonical_instance_id;      // it job completed successfully,
+                                    // the ID of the canonical instance
+    int n_outfiles;                 // number of output files
+
+    int parse(XML_PARSER&);
+    void print();
+};
+
+// Return the state of jobs in a given batch
+// (can specify by either ID or name)
+//
+extern int query_batch(
+    const char* project_url,
+    const char* authenticator,
+    int batch_id,
+    const char batch_name[256],
+    vector<JOB_STATE>& jobs,
     string& error_msg
 );
 
@@ -186,7 +251,17 @@ extern int retire_batch(
     string& error_msg
 );
 
+extern int set_expire_time(
+    const char* project_url,
+    const char* authenticator,
+    const char* batch_name,
+    double expire_time,
+    string& error_msg
+);
+
 extern int ping_server(
     const char* project_url,
     string& error_msg
 );
+
+#endif
