@@ -538,12 +538,6 @@ void get_sandbox_account_service_token() {
 // argv is set up Unix-style, i.e. argv[0] is the program name
 //
 
-// CreateEnvironmentBlock
-typedef BOOL (WINAPI *tCEB)(LPVOID *lpEnvironment, HANDLE hToken, BOOL bInherit);
-// DestroyEnvironmentBlock
-typedef BOOL (WINAPI *tDEB)(LPVOID lpEnvironment);
-
-
 int run_app_windows(
     const char* dir, const char* file, int argc, char *const argv[], HANDLE& id
 ) {
@@ -569,20 +563,9 @@ int run_app_windows(
     get_sandbox_account_interactive_token();
     if (sandbox_account_interactive_token != NULL) {
 
-        // Find CreateEnvironmentBlock/DestroyEnvironmentBlock pointers
-        tCEB    pCEB = NULL;
-        tDEB    pDEB = NULL;
-        HMODULE hUserEnvLib = NULL;
-
-        hUserEnvLib = LoadLibraryA("userenv.dll");
-        if (hUserEnvLib) {
-            pCEB = (tCEB) GetProcAddress(hUserEnvLib, "CreateEnvironmentBlock");
-            pDEB = (tDEB) GetProcAddress(hUserEnvLib, "DestroyEnvironmentBlock");
-        }
-
         // Construct an environment block that contains environment variables that don't
         //   describe the current user.
-        if (!pCEB(&environment_block, sandbox_account_interactive_token, FALSE)) {
+        if (!CreateEnvironmentBlock(&environment_block, sandbox_account_interactive_token, FALSE)) {
             windows_format_error_string(GetLastError(), error_msg, sizeof(error_msg));
             fprintf(stderr, "CreateEnvironmentBlock failed: %s\n", error_msg);
         }
@@ -601,16 +584,11 @@ int run_app_windows(
             &process_info 
         );
 
-        if (!pDEB(environment_block)) {
+        if (!DestroyEnvironmentBlock(environment_block)) {
             windows_format_error_string(GetLastError(), error_msg, sizeof(error_msg));
             fprintf(stderr, "DestroyEnvironmentBlock failed: %s\n", error_msg);
         }
 
-        if (hUserEnvLib) {
-            pCEB = NULL;
-            pDEB = NULL;
-            FreeLibrary(hUserEnvLib);
-        }
     } else {
         retval = CreateProcessA(
             file,
