@@ -348,7 +348,7 @@ struct DISK_LIMITS {
 // summary of a client's request for work, and our response to it
 // Note: this is zeroed out in SCHEDULER_REPLY constructor
 //
-struct WORK_REQ {
+struct WORK_REQ_BASE {
     bool anonymous_platform;
 
     // the following defined if anonymous platform
@@ -377,12 +377,12 @@ struct WORK_REQ {
     bool dont_use_proc_type[NPROC_TYPES];
     bool allow_non_preferred_apps;
     bool allow_beta_work;
-    std::vector<APP_INFO> preferred_apps;
 
     bool has_reliable_version;
         // whether the host has a reliable app version
 
     int effective_ncpus;
+        // # of usable CPUs on host, taking prefs into account
     int effective_ngpus;
 
     // 6.7+ clients send separate requests for different resource types:
@@ -394,15 +394,9 @@ struct WORK_REQ {
     inline bool need_proc_type(int t) {
         return (req_secs[t]>0) || (req_instances[t]>0);
     }
-    inline void clear_cpu_req() {
-        req_secs[PROC_TYPE_CPU] = 0;
-        req_instances[PROC_TYPE_CPU] = 0;
-    }
-    inline void clear_gpu_req() {
-        for (int i=1; i<NPROC_TYPES; i++) {
-            req_secs[i] = 0;
-            req_instances[i] = 0;
-        }
+    inline void clear_req(int proc_type) {
+        req_secs[proc_type] = 0;
+        req_instances[proc_type] = 0;
     }
 
     // older clients send send a single number, the requested duration of jobs
@@ -415,7 +409,8 @@ struct WORK_REQ {
 
     double disk_available;
     double ram, usable_ram;
-    double running_frac;
+    double cpu_available_frac;
+    double gpu_available_frac;
     int njobs_sent;
 
     // The following keep track of the "easiest" job that was rejected
@@ -447,11 +442,6 @@ struct WORK_REQ {
     RESOURCE speed;
     RESOURCE bandwidth;
 
-    std::vector<USER_MESSAGE> no_work_messages;
-    std::vector<BEST_APP_VERSION*> best_app_versions;
-    std::vector<DB_HOST_APP_VERSION> host_app_versions;
-    std::vector<DB_HOST_APP_VERSION> host_app_versions_orig;
-
     // various reasons for not sending jobs (used to explain why)
     //
     bool no_allowed_apps_available;
@@ -459,13 +449,33 @@ struct WORK_REQ {
     bool hr_reject_perm;
     bool outdated_client;
     bool max_jobs_on_host_exceeded;
-    bool max_jobs_on_host_cpu_exceeded;
-    bool max_jobs_on_host_gpu_exceeded;
+    bool max_jobs_on_host_proc_type_exceeded[NPROC_TYPES];
     bool no_jobs_available;     // project has no work right now
     int max_jobs_per_rpc;
-    void add_no_work_message(const char*);
     void get_job_limits();
 
+    bool max_jobs_exceeded() {
+        if (max_jobs_on_host_exceeded) return true;
+        for (int i=0; i<NPROC_TYPES; i++) {
+            if (max_jobs_on_host_proc_type_exceeded[i]) return true;
+        }
+        return false;
+    }
+    void clear() {
+        memset(this, 0, sizeof(WORK_REQ_BASE));
+    }
+
+};
+
+struct WORK_REQ : public WORK_REQ_BASE {
+    std::vector<APP_INFO> preferred_apps;
+    std::vector<USER_MESSAGE> no_work_messages;
+    std::vector<BEST_APP_VERSION*> best_app_versions;
+    std::vector<DB_HOST_APP_VERSION> host_app_versions;
+    std::vector<DB_HOST_APP_VERSION> host_app_versions_orig;
+
+    void add_no_work_message(const char*);
+
     ~WORK_REQ() {}
 };
 
@@ -539,4 +549,5 @@ inline bool is_64b_platform(const char* name) {
     return (strstr(name, "64") != NULL);
 }
 
+extern double available_frac(BEST_APP_VERSION&);
 #endif
