@@ -37,13 +37,14 @@
 #include <sys/time.h>
 #include <sys/param.h>
 
-#include "boinc_db.h"
-#include "util.h"
 #include "backend_lib.h"
+#include "boinc_db.h"
 #include "common_defs.h"
 #include "error_numbers.h"
+#include "filesys.h"
 #include "str_util.h"
 #include "svn_version.h"
+#include "util.h"
 
 #include "sched_config.h"
 #include "credit.h"
@@ -295,6 +296,14 @@ int handle_wu(
                 }
                 break;
             case RESULT_OUTCOME_CLIENT_ERROR:
+                // is user aborted job, don't count it as an error
+                //
+                if (res_item.res_exit_status == EXIT_ABORTED_VIA_GUI) {
+                    nno_reply++;
+                } else {
+                    nerrors++;
+                }
+                break;
             case RESULT_OUTCOME_VALIDATE_ERROR:
                 nerrors++;
                 break;
