@@ -92,6 +92,8 @@ char app_name[256];
 DB_APP app;
 int wu_id_modulus=0;
 int wu_id_remainder=0;
+int wu_id_min=0;
+int wu_id_max=0;
 int one_pass_N_WU=0;
 bool one_pass = false;
 double max_granted_credit = 200 * 1000 * 365;
@@ -101,9 +103,12 @@ bool credit_from_wu = false;
 bool credit_from_runtime = false;
 double max_runtime = 0;
 bool no_credit = false;
+bool dry_run = false;
+int g_argc;
+char **g_argv;
 
 WORKUNIT* g_wup;
-vector<DB_APP_VERSION> app_versions;
+vector<DB_APP_VERSION_VAL> app_versions;
     // cache of app_versions; the PFC statistics of these are
     // updated in memory, and periodically flushed to the DB
 
@@ -142,17 +147,21 @@ int is_valid(
     if (update_credited_job) {
         credited_job.userid = host.userid;
         credited_job.workunitid = long(wu.opaque);
-        retval = credited_job.insert();
-        if (retval) {
-            log_messages.printf(MSG_CRITICAL,
-                "[RESULT#%u] Warning: credited_job insert failed (userid: %d workunit: %f err: %s)\n",
-                result.id, host.userid, wu.opaque, boincerror(retval)
-            );
+        if (dry_run) {
+            log_messages.printf(MSG_NORMAL, "DB not updated (dry run)\n");
         } else {
-            log_messages.printf(MSG_DEBUG,
-                "[RESULT#%u %s] added credited_job record [WU#%u OPAQUE#%f USER#%d]\n",
-                result.id, result.name, wu.id, wu.opaque, host.userid
-            );
+            retval = credited_job.insert();
+            if (retval) {
+                log_messages.printf(MSG_CRITICAL,
+                    "[RESULT#%u] Warning: credited_job insert failed (userid: %d workunit: %f err: %s)\n",
+                    result.id, host.userid, wu.opaque, boincerror(retval)
+                );
+            } else {
+                log_messages.printf(MSG_DEBUG,
+                    "[RESULT#%u %s] added credited_job record [WU#%u OPAQUE#%f USER#%d]\n",
+                    result.id, result.name, wu.id, wu.opaque, host.userid
+                );
+            }
         }
     }
 
@@ -311,15 +320,21 @@ int handle_wu(
                 is_invalid(havv[0]);
             }
             if (hav.host_id && update_hav) {
-                log_messages.printf(MSG_NORMAL,
-                    "[HOST#%d AV#%d] [outlier=%d] Updating HAV in db.  pfc.n=%f->%f\n",
-                    havv[0].host_id, havv[0].app_version_id, result.runtime_outlier, hav_orig.pfc.n,havv[0].pfc.n);
-                retval=havv[0].update_validator(hav_orig);
-                if (retval) {
-                    log_messages.printf(MSG_CRITICAL,
-                        "[HOST#%d AV%d] hav.update_validator() failed: %s\n",
-                        hav.host_id, hav.app_version_id, boincerror(retval)
+                if (dry_run) {
+                    log_messages.printf(MSG_NORMAL, "DB not updated (dry run)\n");
+                } else {
+                    log_messages.printf(MSG_NORMAL,
+                        "[HOST#%d AV#%d] [outlier=%d] Updating HAV in DB.  pfc.n=%f->%f\n",
+                        havv[0].host_id, havv[0].app_version_id,
+                        result.runtime_outlier, hav_orig.pfc.n, havv[0].pfc.n
                     );
+                    retval=havv[0].update_validator(hav_orig);
+                    if (retval) {
+                        log_messages.printf(MSG_CRITICAL,
+                            "[HOST#%d AV%d] hav.update_validator() failed: %s\n",
+                            hav.host_id, hav.app_version_id, boincerror(retval)
+                        );
+                    }
                 }
             }
             host.update_diff_validator(host_initial);
@@ -328,13 +343,16 @@ int handle_wu(
                     "[RESULT#%u %s] granted_credit %f\n",
                     result.id, result.name, result.granted_credit
                 );
-
-                retval = validator.update_result(result);
-                if (retval) {
-                    log_messages.printf(MSG_CRITICAL,
-                        "[RESULT#%u %s] Can't update result: %s\n",
-                        result.id, result.name, boincerror(retval)
-                    );
+                if (dry_run) {
+                    log_messages.printf(MSG_NORMAL, "DB not updated (dry run)\n");
+                } else {
+                    retval = validator.update_result(result);
+                    if (retval) {
+                        log_messages.printf(MSG_CRITICAL,
+                            "[RESULT#%u %s] Can't update result: %s\n",
+                            result.id, result.name, boincerror(retval)
+                        );
+                    }
                 }
             }
         }
@@ -537,28 +555,34 @@ int handle_wu(
                     break;
                 }
 
-                if (hav.host_id) {
-                    log_messages.printf(MSG_NORMAL,
-                        "[HOST#%d AV#%d] [outlier=%d] Updating HAV in db.  pfc.n=%f->%f\n",
-                        hav.host_id, hav.app_version_id, result.runtime_outlier, hav_orig.pfc.n,hav.pfc.n);
-                    retval = hav.update_validator(hav_orig);
-                    if (retval) {
-                        log_messages.printf(MSG_CRITICAL,
-                            "[HOST#%d AV%d] hav.update_validator() failed: %s\n",
-                            hav.host_id, hav.app_version_id, boincerror(retval)
+                if (dry_run) {
+                    log_messages.printf(MSG_NORMAL, "DB not updated (dry run)\n");
+                } else {
+                    if (hav.host_id) {
+                        log_messages.printf(MSG_NORMAL,
+                            "[HOST#%d AV#%d] [outlier=%d] Updating HAV in DB.  pfc.n=%f->%f\n",
+                            hav.host_id, hav.app_version_id,
+                            result.runtime_outlier, hav_orig.pfc.n, hav.pfc.n
                         );
+                        retval = hav.update_validator(hav_orig);
+                        if (retval) {
+                            log_messages.printf(MSG_CRITICAL,
+                                "[HOST#%d AV%d] hav.update_validator() failed: %s\n",
+                                hav.host_id, hav.app_version_id, boincerror(retval)
+                            );
+                        }
                     }
-                }
-                if (update_host) {
-                    retval = host.update_diff_validator(host_initial);
-                }
-                if (update_result) {
-                    retval = validator.update_result(result);
-                    if (retval) {
-                        log_messages.printf(MSG_CRITICAL,
-                            "[RESULT#%u %s] result.update() failed: %s\n",
-                            result.id, result.name, boincerror(retval)
-                        );
+                    if (update_host) {
+                        retval = host.update_diff_validator(host_initial);
+                    }
+                    if (update_result) {
+                        retval = validator.update_result(result);
+                        if (retval) {
+                            log_messages.printf(MSG_CRITICAL,
+                                "[RESULT#%u %s] result.update() failed: %s\n",
+                                result.id, result.name, boincerror(retval)
+                            );
+                        }
                     }
                 }
             }
@@ -588,12 +612,16 @@ int handle_wu(
 
                     result.server_state = RESULT_SERVER_STATE_OVER;
                     result.outcome = RESULT_OUTCOME_DIDNT_NEED;
-                    retval = validator.update_result(result);
-                    if (retval) {
-                        log_messages.printf(MSG_CRITICAL,
-                            "[RESULT#%u %s] result.update() failed: %s\n",
-                            result.id, result.name, boincerror(retval)
-                        );
+                    if (dry_run) {
+                        log_messages.printf(MSG_NORMAL, "DB not updated (dry run)\n");
+                    } else {
+                        retval = validator.update_result(result);
+                        if (retval) {
+                            log_messages.printf(MSG_CRITICAL,
+                                "[RESULT#%u %s] result.update() failed: %s\n",
+                                result.id, result.name, boincerror(retval)
+                            );
+                        }
                     }
                 }
             } else {
@@ -639,13 +667,17 @@ leave:
 
     wu.need_validate = 0;
     
-    retval = validator.update_workunit(wu);
-    if (retval) {
-        log_messages.printf(MSG_CRITICAL,
-            "[WU#%u %s] update_workunit() failed: %s\n",
-            wu.id, wu.name, boincerror(retval)
-        );
-        return retval;
+    if (dry_run) {
+        log_messages.printf(MSG_NORMAL, "DB not updated (dry run)\n");
+    } else {
+        retval = validator.update_workunit(wu);
+        if (retval) {
+            log_messages.printf(MSG_CRITICAL,
+                "[WU#%u %s] update_workunit() failed: %s\n",
+                wu.id, wu.name, boincerror(retval)
+            );
+            return retval;
+        }
     }
     return 0;
 }
@@ -663,7 +695,8 @@ bool do_validate_scan() {
     //
     while (1) {
         retval = validator.enumerate(
-            app.id, SELECT_LIMIT, wu_id_modulus, wu_id_remainder, items
+            app.id, SELECT_LIMIT, wu_id_modulus, wu_id_remainder,
+            wu_id_min, wu_id_max, items
         );
         if (retval) {
             if (retval != ERR_DB_NOT_FOUND) {
@@ -713,6 +746,7 @@ int main_loop() {
             daemon_sleep(sleep_interval);
 #endif
         }
+        if (one_pass) break;
     }
     return 0;
 }
@@ -730,7 +764,10 @@ int main(int argc, char** argv) {
       "Optional arguments:\n"
       "  --one_pass_N_WU N       Validate at most N WUs, then exit\n"
       "  --one_pass              Make one pass through WU table, then exit\n"
+      "  --dry_run               Don't update db, just write logs (for debugging)\n"
       "  --mod n i               Process only WUs with (id mod n) == i\n"
+      "  --max_wu_id n           Process only WUs with id <= n\n"
+      "  --min_wu_id n           Process only WUs with id >= n\n"
       "  --max_granted_credit X  Grant no more than this amount of credit to a result\n"
       "  --update_credited_job   Add record to credited_job table after granting credit\n"
       "  --credit_from_wu        Credit is specified in WU XML\n"
@@ -759,6 +796,8 @@ int main(int argc, char** argv) {
             one_pass = true;
         } else if (is_arg(argv[i], "sleep_interval")) {
             sleep_interval = atoi(argv[++i]);
+        } else if (is_arg(argv[i], "dry_run")) {
+            dry_run = true;
         } else if (is_arg(argv[i], "one_pass")) {
             one_pass = true;
         } else if (is_arg(argv[i], "app")) {
@@ -770,6 +809,10 @@ int main(int argc, char** argv) {
         } else if (is_arg(argv[i], "mod")) {
             wu_id_modulus = atoi(argv[++i]);
             wu_id_remainder = atoi(argv[++i]);
+        } else if (is_arg(argv[i], "min_wu_id")) {
+            wu_id_min = atoi(argv[++i]);
+        } else if (is_arg(argv[i], "max_wu_id")) {
+            wu_id_max = atoi(argv[++i]);
         } else if (is_arg(argv[i], "max_granted_credit")) {
             max_granted_credit = atof(argv[++i]);
         } else if (is_arg(argv[i], "update_credited_job")) {
@@ -782,14 +825,11 @@ int main(int argc, char** argv) {
         } else if (is_arg(argv[i], "no_credit")) {
             no_credit = true;
         } else {
-            fprintf(stderr,
-                "Invalid option '%s'\nTry `%s --help` for more information\n",
-                argv[i], argv[0]
-            );
-            log_messages.printf(MSG_CRITICAL, "unrecognized arg: %s\n", argv[i]);
-            exit(1);
+            //log_messages.printf(MSG_CRITICAL, "unrecognized arg: %s\n", argv[i]);
         }
     }
+    g_argc = argc;
+    g_argv = argv;
 
     if (app_name[0] == 0) {
         log_messages.printf(MSG_CRITICAL,
@@ -832,6 +872,16 @@ int main(int argc, char** argv) {
             "Modulus %d, remainder %d\n", wu_id_modulus, wu_id_remainder
         );
     }
+    if (wu_id_min) {
+        log_messages.printf(MSG_NORMAL,
+            "min wu id %d\n", wu_id_min
+        );
+    }
+    if (wu_id_max) {
+        log_messages.printf(MSG_NORMAL,
+            "max wu id %d\n", wu_id_max
+        );
+    }
 
     install_stop_signal_handler();
 
